class Guid(object,IFormattable,IComparable,IComparable[Guid],IEquatable[Guid]):
 """
 Represents a globally unique identifier (GUID).

 

 Guid(b: Array[Byte])

 Guid(a: UInt32,b: UInt16,c: UInt16,d: Byte,e: Byte,f: Byte,g: Byte,h: Byte,i: Byte,j: Byte,k: Byte)

 Guid(a: int,b: Int16,c: Int16,d: Array[Byte])

 Guid(a: int,b: Int16,c: Int16,d: Byte,e: Byte,f: Byte,g: Byte,h: Byte,i: Byte,j: Byte,k: Byte)

 Guid(g: str)
 """
 def CompareTo(self,value):
  """
  CompareTo(self: Guid,value: Guid) -> int

  

   Compares this instance to a specified System.Guid object and returns an indication of their 

    relative values.

  

  

   value: An object to compare to this instance.

   Returns: A signed number indicating the relative values of this instance and value.Return value 

    Description A negative integer This instance is less than value. Zero This instance is equal to 

    value. A positive integer This instance is greater than value.

  

  CompareTo(self: Guid,value: object) -> int

  

   Compares this instance to a specified object and returns an indication of their relative values.

  

   value: An object to compare,or null.

   Returns: A signed number indicating the relative values of this instance and value.Return value 

    Description A negative integer This instance is less than value. Zero This instance is equal to 

    value. A positive integer This instance is greater than value,or value is null.
  """
  pass
 def Equals(self,*__args):
  """
  Equals(self: Guid,g: Guid) -> bool

  

   Returns a value indicating whether this instance and a specified System.Guid object represent 

    the same value.

  

  

   g: An object to compare to this instance.

   Returns: true if g is equal to this instance; otherwise,false.

  Equals(self: Guid,o: object) -> bool

  

   Returns a value that indicates whether this instance is equal to a specified object.

  

   o: The object to compare with this instance.

   Returns: true if o is a System.Guid that has the same value as this instance; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: Guid) -> int

  

   Returns the hash code for this instance.

   Returns: The hash code for this instance.
  """
  pass
 @staticmethod
 def NewGuid():
  """
  NewGuid() -> Guid

  

   Initializes a new instance of the System.Guid structure.

   Returns: A new GUID object.
  """
  pass
 @staticmethod
 def Parse(input):
  """
  Parse(input: str) -> Guid

  

   Converts the string representation of a GUID to the equivalent System.Guid structure.

  

   input: The GUID to convert.

   Returns: A structure that contains the value that was parsed.
  """
  pass
 @staticmethod
 def ParseExact(input,format):
  """
  ParseExact(input: str,format: str) -> Guid

  

   Converts the string representation of a GUID to the equivalent System.Guid structure,provided 

    that the string is in the specified format.

  

  

   input: The GUID to convert.

   format: One of the following specifiers that indicates the exact format to use when interpreting input: 

    "N","D","B","P",or "X".

  

   Returns: A structure that contains the value that was parsed.
  """
  pass
 def ToByteArray(self):
  """
  ToByteArray(self: Guid) -> Array[Byte]

  

   Returns a 16-element byte array that contains the value of this instance.

   Returns: A 16-element byte array.
  """
  pass
 def ToString(self,format=None,provider=None):
  """
  ToString(self: Guid,format: str,provider: IFormatProvider) -> str

  

   Returns a string representation of the value of this instance of the System.Guid structure,

    according to the provided format specifier and culture-specific format information.

  

  

   format: A single format specifier that indicates how to format the value of this System.Guid. The format 

    parameter can be "N","D","B","P",or "X". If format is null or an empty string (""),"D" is 

    used.

  

   provider: (Reserved) An object that supplies culture-specific formatting services.

   Returns: The value of this System.Guid,represented as a series of lowercase hexadecimal digits in the 

    specified format.

  

  ToString(self: Guid,format: str) -> str

  

   Returns a string representation of the value of this System.Guid instance,according to the 

    provided format specifier.

  

  

   format: A single format specifier that indicates how to format the value of this System.Guid. The format 

    parameter can be "N","D","B","P",or "X". If format is null or an empty string (""),"D" is 

    used.

  

   Returns: The value of this System.Guid,represented as a series of lowercase hexadecimal digits in the 

    specified format.

  

  ToString(self: Guid) -> str

  

   Returns a string representation of the value of this instance in registry format.

   Returns: The value of this System.Guid,formatted using the "D" format specifier as follows: 

    xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx where the value of the GUID is represented as a series of 

    lowercase hexadecimal digits in groups of 8,4,4,4,and 12 digits and separated by hyphens. An 

    example of a return value is "382c74c3-721d-4f34-80e5-57657b6cbc27".
  """
  pass
 @staticmethod
 def TryParse(input,result):
  """
  TryParse(input: str) -> (bool,Guid)

  

   Converts the string representation of a GUID to the equivalent System.Guid structure.

  

   input: The GUID to convert.

   Returns: true if the parse operation was successful; otherwise,false.
  """
  pass
 @staticmethod
 def TryParseExact(input,format,result):
  """
  TryParseExact(input: str,format: str) -> (bool,Guid)

  

   Converts the string representation of a GUID to the equivalent System.Guid structure,provided 

    that the string is in the specified format.

  

  

   input: The GUID to convert.

   format: One of the following specifiers that indicates the exact format to use when interpreting input: 

    "N","D","B","P",or "X".

  

   Returns: true if the parse operation was successful; otherwise,false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,b: Array[Byte])

  __new__(cls: type,a: UInt32,b: UInt16,c: UInt16,d: Byte,e: Byte,f: Byte,g: Byte,h: Byte,i: Byte,j: Byte,k: Byte)

  __new__(cls: type,a: int,b: Int16,c: Int16,d: Array[Byte])

  __new__(cls: type,a: int,b: Int16,c: Int16,d: Byte,e: Byte,f: Byte,g: Byte,h: Byte,i: Byte,j: Byte,k: Byte)

  __new__(cls: type,g: str)

  __new__[Guid]() -> Guid
  """
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __str__(self,*args):
  pass
 Empty=None




# encoding: utf-8
# module System.Security.AccessControl calls itself AccessControl
# from mscorlib,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089,System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# functions

def AccessRule(*args,**kwargs): # real signature unknown
 """ Represents a combination of a user's identity,an access mask,and an access control type (allow or deny). An System.Security.AccessControl.AccessRule object also contains information about the how the rule is inherited by child objects and how that inheritance is propagated. """
 pass
def AuditRule(*args,**kwargs): # real signature unknown
 """ Represents a combination of a user's identity and an access mask. An System.Security.AccessControl.AuditRule object also contains information about how the rule is inherited by child objects,how that inheritance is propagated,and for what conditions it is audited. """
 pass
def ObjectSecurity(*args,**kwargs): # real signature unknown
 """ Provides the ability to control access to objects without direct manipulation of Access Control Lists (ACLs). This class is the abstract base class for the System.Security.AccessControl.CommonObjectSecurity and System.Security.AccessControl.DirectoryObjectSecurity classes. """
 pass
# classes
from AccessControl_parts.AccessControlActions import AccessControlActions
from AccessControl_parts.AccessControlModification import AccessControlModification
from AccessControl_parts.AccessControlSections import AccessControlSections
from AccessControl_parts.AccessControlType import AccessControlType
from AccessControl_parts.AceEnumerator import AceEnumerator
from AccessControl_parts.AceFlags import AceFlags
from AccessControl_parts.AceQualifier import AceQualifier
from AccessControl_parts.AceType import AceType
from AccessControl_parts.AuditFlags import AuditFlags
from AccessControl_parts.AuthorizationRule import AuthorizationRule
from AccessControl_parts.AuthorizationRuleCollection import AuthorizationRuleCollection
from AccessControl_parts.GenericAce import GenericAce
from AccessControl_parts.KnownAce import KnownAce
from AccessControl_parts.QualifiedAce import QualifiedAce
from AccessControl_parts.CommonAce import CommonAce
from AccessControl_parts.GenericAcl import GenericAcl
from AccessControl_parts.CommonAcl import CommonAcl
from AccessControl_parts.CommonObjectSecurity import CommonObjectSecurity
from AccessControl_parts.GenericSecurityDescriptor import GenericSecurityDescriptor
from AccessControl_parts.CommonSecurityDescriptor import CommonSecurityDescriptor
from AccessControl_parts.CompoundAce import CompoundAce
from AccessControl_parts.CompoundAceType import CompoundAceType
from AccessControl_parts.ControlFlags import ControlFlags
from AccessControl_parts.CryptoKeyAccessRule import CryptoKeyAccessRule
from AccessControl_parts.CryptoKeyAuditRule import CryptoKeyAuditRule
from AccessControl_parts.CryptoKeyRights import CryptoKeyRights
from AccessControl_parts.NativeObjectSecurity import NativeObjectSecurity
from AccessControl_parts.CryptoKeySecurity import CryptoKeySecurity
from AccessControl_parts.CustomAce import CustomAce
from AccessControl_parts.DirectoryObjectSecurity import DirectoryObjectSecurity
from AccessControl_parts.FileSystemSecurity import FileSystemSecurity
from AccessControl_parts.DirectorySecurity import DirectorySecurity
from AccessControl_parts.DiscretionaryAcl import DiscretionaryAcl
from AccessControl_parts.EventWaitHandleAccessRule import EventWaitHandleAccessRule
from AccessControl_parts.EventWaitHandleAuditRule import EventWaitHandleAuditRule
from AccessControl_parts.EventWaitHandleRights import EventWaitHandleRights
from AccessControl_parts.EventWaitHandleSecurity import EventWaitHandleSecurity
from AccessControl_parts.FileSecurity import FileSecurity
from AccessControl_parts.FileSystemAccessRule import FileSystemAccessRule
from AccessControl_parts.FileSystemAuditRule import FileSystemAuditRule
from AccessControl_parts.FileSystemRights import FileSystemRights
from AccessControl_parts.InheritanceFlags import InheritanceFlags
from AccessControl_parts.MutexAccessRule import MutexAccessRule
from AccessControl_parts.MutexAuditRule import MutexAuditRule
from AccessControl_parts.MutexRights import MutexRights
from AccessControl_parts.MutexSecurity import MutexSecurity
from AccessControl_parts.ObjectAccessRule import ObjectAccessRule
from AccessControl_parts.ObjectAce import ObjectAce
from AccessControl_parts.ObjectAceFlags import ObjectAceFlags
from AccessControl_parts.ObjectAuditRule import ObjectAuditRule
from AccessControl_parts.PrivilegeNotHeldException import PrivilegeNotHeldException
from AccessControl_parts.PropagationFlags import PropagationFlags
from AccessControl_parts.RawAcl import RawAcl
from AccessControl_parts.RawSecurityDescriptor import RawSecurityDescriptor
from AccessControl_parts.RegistryAccessRule import RegistryAccessRule
from AccessControl_parts.RegistryAuditRule import RegistryAuditRule
from AccessControl_parts.RegistryRights import RegistryRights
from AccessControl_parts.RegistrySecurity import RegistrySecurity
from AccessControl_parts.ResourceType import ResourceType
from AccessControl_parts.SecurityInfos import SecurityInfos
from AccessControl_parts.SemaphoreAccessRule import SemaphoreAccessRule
from AccessControl_parts.SemaphoreAuditRule import SemaphoreAuditRule
from AccessControl_parts.SemaphoreRights import SemaphoreRights
from AccessControl_parts.SemaphoreSecurity import SemaphoreSecurity
from AccessControl_parts.SystemAcl import SystemAcl



class DataGridViewCellValidatingEventArgs(CancelEventArgs):
 """ Provides data for the System.Windows.Forms.DataGridView.CellValidating event of a System.Windows.Forms.DataGridView control. """
 ColumnIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the column index of the cell that needs to be validated.



Get: ColumnIndex(self: DataGridViewCellValidatingEventArgs) -> int



"""

 FormattedValue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the formatted contents of the cell that needs to be validated.



Get: FormattedValue(self: DataGridViewCellValidatingEventArgs) -> object



"""

 RowIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the row index of the cell that needs to be validated.



Get: RowIndex(self: DataGridViewCellValidatingEventArgs) -> int



"""





"""COMMAND-LINE SPECIFIC STUFF."""

import sys
import optparse
import codecs
import warnings
import markdown
try:
    import yaml
except ImportError:  # pragma: no cover
    import json as yaml

import logging
from logging import DEBUG, WARNING, CRITICAL

logger = logging.getLogger('MARKDOWN')


def parse_options(args=None, values=None):
    """Define and parse `optparse` options for command-line usage."""
    usage = """%prog [options] [INPUTFILE]
       (STDIN is assumed if no INPUTFILE is given)"""
    desc = "A Python implementation of John Gruber's Markdown. " \
           "https://pythonhosted.org/Markdown/"
    ver = "%%prog %s" % markdown.version

    parser = optparse.OptionParser(usage=usage, description=desc, version=ver)
    parser.add_option("-f", "--file", dest="filename", default=None,
                      help="Write output to OUTPUT_FILE. Defaults to STDOUT.",
                      metavar="OUTPUT_FILE")
    parser.add_option("-e", "--encoding", dest="encoding",
                      help="Encoding for input and output files.",)
    parser.add_option("-s", "--safe", dest="safe", default=False,
                      metavar="SAFE_MODE",
                      help="Deprecated! 'replace', 'remove' or 'escape' HTML "
                      "tags in input")
    parser.add_option("-o", "--output_format", dest="output_format",
                      default='xhtml1', metavar="OUTPUT_FORMAT",
                      help="'xhtml1' (default), 'html4' or 'html5'.")
    parser.add_option("-n", "--no_lazy_ol", dest="lazy_ol",
                      action='store_false', default=True,
                      help="Observe number of first item of ordered lists.")
    parser.add_option("-x", "--extension", action="append", dest="extensions",
                      help="Load extension EXTENSION.", metavar="EXTENSION")
    parser.add_option("-c", "--extension_configs",
                      dest="configfile", default=None,
                      help="Read extension configurations from CONFIG_FILE. "
                      "CONFIG_FILE must be of JSON or YAML format. YAML"
                      "format requires that a python YAML library be "
                      "installed. The parsed JSON or YAML must result in a "
                      "python dictionary which would be accepted by the "
                      "'extension_configs' keyword on the markdown.Markdown "
                      "class. The extensions must also be loaded with the "
                      "`--extension` option.",
                      metavar="CONFIG_FILE")
    parser.add_option("-q", "--quiet", default=CRITICAL,
                      action="store_const", const=CRITICAL+10, dest="verbose",
                      help="Suppress all warnings.")
    parser.add_option("-v", "--verbose",
                      action="store_const", const=WARNING, dest="verbose",
                      help="Print all warnings.")
    parser.add_option("--noisy",
                      action="store_const", const=DEBUG, dest="verbose",
                      help="Print debug messages.")

    (options, args) = parser.parse_args(args, values)

    if len(args) == 0:
        input_file = None
    else:
        input_file = args[0]

    if not options.extensions:
        options.extensions = []

    extension_configs = {}
    if options.configfile:
        with codecs.open(
            options.configfile, mode="r", encoding=options.encoding
        ) as fp:
            try:
                extension_configs = yaml.load(fp)
            except Exception as e:
                message = "Failed parsing extension config file: %s" % \
                          options.configfile
                e.args = (message,) + e.args[1:]
                raise

    opts = {
        'input': input_file,
        'output': options.filename,
        'extensions': options.extensions,
        'extension_configs': extension_configs,
        'encoding': options.encoding,
        'output_format': options.output_format,
        'lazy_ol': options.lazy_ol
    }

    if options.safe:
        # Avoid deprecation warning if user didn't set option
        opts['safe_mode'] = options.safe

    return opts, options.verbose


def run():  # pragma: no cover
    """Run Markdown from the command line."""
    # Parse options and adjust logging level if necessary
    options, logging_level = parse_options()
    if not options:
        sys.exit(2)
    logger.setLevel(logging_level)
    console_handler = logging.StreamHandler()
    logger.addHandler(console_handler)
    if logging_level <= WARNING:
        # Ensure deprecation warnings get displayed
        warnings.filterwarnings('default')
        logging.captureWarnings(True)
        warn_logger = logging.getLogger('py.warnings')
        warn_logger.addHandler(console_handler)

    # Run
    markdown.markdownFromFile(**options)


if __name__ == '__main__':  # pragma: no cover
    # Support running module as a commandline command.
    # Python 2.7 & 3.x do: `python -m markdown [options] [args]`.
    run()



class BufferedGraphics(object,IDisposable):
 """ Provides a graphics buffer for double buffering. """
 def Dispose(self):
  """
  Dispose(self: BufferedGraphics)

   Releases all resources used by the System.Drawing.BufferedGraphics object.
  """
  pass
 def Render(self,*__args):
  """
  Render(self: BufferedGraphics,targetDC: IntPtr)

   Writes the contents of the graphics buffer to the device context associated with the specified 

    System.IntPtr handle.

  

  

   targetDC: An System.IntPtr that points to the device context to which to write the contents of the 

    graphics buffer.

  

  Render(self: BufferedGraphics,target: Graphics)

   Writes the contents of the graphics buffer to the specified System.Drawing.Graphics object.

  

   target: A System.Drawing.Graphics object to which to write the contents of the graphics buffer.

  Render(self: BufferedGraphics)

   Writes the contents of the graphics buffer to the default device.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Graphics=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Drawing.Graphics object that outputs to the graphics buffer.



Get: Graphics(self: BufferedGraphics) -> Graphics



"""





class IMessageFilter:
 """ Defines a message filter interface. """
 def PreFilterMessage(self,m):
  """
  PreFilterMessage(self: IMessageFilter,m: Message) -> (bool,Message)

  

   Filters out a message before it is dispatched.

  

   m: The message to be dispatched. You cannot modify this message.

   Returns: true to filter the message and stop it from being dispatched; false to allow the message to 

    continue to the next filter or control.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



from typing import Tuple, Set, Iterable, List


class AssetProperty:
    @property
    def Name(self) -> str: ...
    @property
    def Type(self) -> AssetPropertyType: ...
    def GetTypeName(type: AssetPropertyType) -> str: ...
    @property
    def NumberOfConnectedProperties(self) -> int: ...
    @property
    def IsReadOnly(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetConnectedProperty(self, index: int) -> AssetProperty: ...
    def GetSingleConnectedAsset(self) -> Asset: ...
    def GetAllConnectedProperties(self) -> List[AssetProperty]: ...
    def IsEditable(self) -> bool: ...
    def AddConnectedAsset(self, schema: str) -> None: ...
    def AddCopyAsConnectedAsset(self, pRenderingAsset: Asset) -> None: ...
    def RemoveConnectedAsset(self) -> None: ...
    def IsValidSchemaIdentifier(self, schemaID: str) -> bool: ...
    def Dispose(self) -> None: ...


class AssetProperties(AssetProperty):
    @property
    def Item(self, index: int) -> AssetProperty: ...
    @property
    def Size(self) -> int: ...
    def FindByName(self, name: str) -> AssetProperty: ...
    def Get(self, index: int) -> AssetProperty: ...
    def IsValidIndex(self, index: int) -> bool: ...


class Asset(AssetProperties):
    @property
    def Title(self) -> str: ...
    @property
    def LibraryName(self) -> str: ...
    @property
    def AssetType(self) -> AssetType: ...


class AssetPropertyType:
    Unknown = 0
    Properties = 1
    Boolean = 2
    Enumeration = 3
    Integer = 4
    Float = 5
    Double1 = 6
    Double2 = 7
    Double3 = 8
    Double4 = 9
    Double44 = 10
    String = 11
    Time = 12
    Distance = 14
    Asset = 15
    Reference = 16
    Longlong = 17
    ULonglong = 18
    List = 19
    Float3 = 20


class AssetType:
    Appearance = 4
    Content = 5


class AssetPropertyTime(AssetProperty):
    @property
    def Value(self) -> DateTime: ...


class AssetSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> AssetSetIterator: ...
    def ReverseIterator(self) -> AssetSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: Asset) -> bool: ...
    def Insert(self, item: Asset) -> bool: ...
    def Erase(self, item: Asset) -> int: ...


class AssetSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class AssetPropertyDoubleArray2d(AssetProperty):
    @property
    def Value(self) -> DoubleArray: ...


class AssetPropertyDoubleMatrix44(AssetProperty):
    @property
    def Value(self) -> DoubleArray: ...


class AssetPropertyFloatArray(AssetProperty):
    def GetValue(self) -> List[Single]: ...


class AssetPropertyInt64(AssetProperty):
    @property
    def Value(self) -> Int64: ...


class AssetPropertyUInt64(AssetProperty):
    @property
    def Value(self) -> UInt64: ...


class AssetPropertyBoolean(AssetProperty):
    @property
    def Value(self) -> bool: ...
    @Value.setter
    def Value(self, value: bool) -> None: ...


class AssetPropertyDistance(AssetProperty):
    @property
    def Value(self) -> float: ...
    @Value.setter
    def Value(self, value: float) -> None: ...
    @property
    def DisplayUnitType(self) -> DisplayUnitType: ...
    def IsValidValue(self, value: float) -> bool: ...
    def GetUnitTypeId(self) -> ForgeTypeId: ...


class AssetPropertyDouble(AssetProperty):
    @property
    def Value(self) -> float: ...
    @Value.setter
    def Value(self, value: float) -> None: ...
    def IsValidValue(self, value: float) -> bool: ...


class AssetPropertyDoubleArray3d(AssetProperty):
    def GetValueAsDoubles(self) -> List[float]: ...
    def GetValueAsXYZ(self) -> XYZ: ...
    def IsValidValue(self, xyz: XYZ) -> bool: ...
    def SetValueAsXYZ(self, xyz: XYZ) -> None: ...


class AssetPropertyDoubleArray4d(AssetProperty):
    def GetValueAsDoubles(self) -> List[float]: ...
    @overload
    def IsValidValue(self, color: Color) -> bool: ...
    @overload
    def IsValidValue(self, value: List[float]) -> bool: ...
    def SetValueAsDoubles(self, value: List[float]) -> None: ...
    def GetValueAsColor(self) -> Color: ...
    def SetValueAsColor(self, color: Color) -> None: ...


class AssetPropertyEnum(AssetProperty):
    @property
    def Value(self) -> int: ...
    @Value.setter
    def Value(self, value: int) -> None: ...
    def IsValidValue(self, value: int) -> bool: ...


class AssetPropertyFloat(AssetProperty):
    @property
    def Value(self) -> Single: ...
    @Value.setter
    def Value(self, value: Single) -> None: ...
    def IsValidValue(self, value: Single) -> bool: ...


class AssetPropertyInteger(AssetProperty):
    @property
    def Value(self) -> int: ...
    @Value.setter
    def Value(self, value: int) -> None: ...
    def IsValidValue(self, value: int) -> bool: ...


class AssetPropertyList(AssetProperty):
    def GetValue(self) -> List[AssetProperty]: ...
    def SetValue(self, value: List[AssetProperty]) -> None: ...
    def IsValidValue(self, value: List[AssetProperty]) -> bool: ...
    def AddNewAssetPropertyDouble(self, value: float) -> None: ...
    def AddNewAssetAsColor(self, value: Color) -> None: ...
    def AddNewAssetPropertyInteger(self, value: int) -> None: ...
    def InsertNewAssetPropertyDouble(self, value: float, index: int) -> None: ...
    def InsertNewAssetAsColor(self, value: Color, index: int) -> None: ...
    def InsertNewAssetPropertyInteger(self, value: int, index: int) -> None: ...
    def RemoveAssetProperty(self, index: int) -> None: ...


class AssetPropertyReference(AssetProperty):


class AssetPropertyString(AssetProperty):
    @property
    def Value(self) -> str: ...
    @Value.setter
    def Value(self, value: str) -> None: ...
    def IsValidValue(self, value: str) -> bool: ...


class AdvancedGlazing:
    @property
    def GlazingTransmissionColor() -> str: ...
    @property
    def GlazingTransmissionRoughness() -> str: ...
    @property
    def GlazingF0() -> str: ...
    @property
    def GlazingBackfaceCulling() -> str: ...
    @property
    def SurfaceAlbedo() -> str: ...
    @property
    def SurfaceAnisotropy() -> str: ...
    @property
    def SurfaceNormal() -> str: ...
    @property
    def SurfaceCutout() -> str: ...
    @property
    def SurfaceRotation() -> str: ...
    @property
    def SurfaceRoughness() -> str: ...
    @property
    def SurfaceNdfType() -> str: ...


class AdvancedLayered:
    @property
    def LayeredBottomF0() -> str: ...
    @property
    def LayeredF0() -> str: ...
    @property
    def LayeredFraction() -> str: ...
    @property
    def LayeredDiffuse() -> str: ...
    @property
    def LayeredAnisotropy() -> str: ...
    @property
    def LayeredNormal() -> str: ...
    @property
    def LayeredRotation() -> str: ...
    @property
    def LayeredRoughness() -> str: ...
    @property
    def LayeredNdfType() -> str: ...
    @property
    def SurfaceAlbedo() -> str: ...
    @property
    def SurfaceAnisotropy() -> str: ...
    @property
    def SurfaceNormal() -> str: ...
    @property
    def SurfaceCutout() -> str: ...
    @property
    def SurfaceRotation() -> str: ...
    @property
    def SurfaceRoughness() -> str: ...
    @property
    def SurfaceNdfType() -> str: ...


class AdvancedMetal:
    @property
    def MetalF0() -> str: ...
    @property
    def SurfaceAlbedo() -> str: ...
    @property
    def SurfaceAnisotropy() -> str: ...
    @property
    def SurfaceNormal() -> str: ...
    @property
    def SurfaceCutout() -> str: ...
    @property
    def SurfaceRotation() -> str: ...
    @property
    def SurfaceRoughness() -> str: ...
    @property
    def SurfaceNdfType() -> str: ...


class AdvancedOpaque:
    @property
    def OpaqueAlbedo() -> str: ...
    @property
    def OpaqueF0() -> str: ...
    @property
    def OpaqueTranslucency() -> str: ...
    @property
    def OpaqueMfp() -> str: ...
    @property
    def OpaqueMfpModifier() -> str: ...
    @property
    def OpaqueEmission() -> str: ...
    @property
    def OpaqueLuminance() -> str: ...
    @property
    def OpaqueLuminanceModifier() -> str: ...
    @property
    def SurfaceAlbedo() -> str: ...
    @property
    def SurfaceAnisotropy() -> str: ...
    @property
    def SurfaceNormal() -> str: ...
    @property
    def SurfaceCutout() -> str: ...
    @property
    def SurfaceRotation() -> str: ...
    @property
    def SurfaceRoughness() -> str: ...
    @property
    def SurfaceNdfType() -> str: ...


class AdvancedTransparent:
    @property
    def TransparentColor() -> str: ...
    @property
    def TransparentDistance() -> str: ...
    @property
    def TransparentIor() -> str: ...
    @property
    def SurfaceAlbedo() -> str: ...
    @property
    def SurfaceAnisotropy() -> str: ...
    @property
    def SurfaceNormal() -> str: ...
    @property
    def SurfaceCutout() -> str: ...
    @property
    def SurfaceRotation() -> str: ...
    @property
    def SurfaceRoughness() -> str: ...
    @property
    def SurfaceNdfType() -> str: ...


class AdvancedWood:
    @property
    def WoodRingThickness() -> str: ...
    @property
    def WoodLatewoodRatio() -> str: ...
    @property
    def WoodEarlywoodSharpness() -> str: ...
    @property
    def WoodLatewoodSharpness() -> str: ...
    @property
    def WoodEarlyColor() -> str: ...
    @property
    def WoodLateColorPower() -> str: ...
    @property
    def WoodSecondaryColorPower() -> str: ...
    @property
    def WoodUseManualLateColor() -> str: ...
    @property
    def WoodManualLateColor() -> str: ...
    @property
    def WoodUsePores() -> str: ...
    @property
    def WoodPoreType() -> str: ...
    @property
    def WoodPoreCellDim() -> str: ...
    @property
    def WoodPoreRadius() -> str: ...
    @property
    def WoodPoreColorPower() -> str: ...
    @property
    def WoodPoreDepth() -> str: ...
    @property
    def WoodUseRays() -> str: ...
    @property
    def WoodRayColorPower() -> str: ...
    @property
    def WoodRaySegLengthZ() -> str: ...
    @property
    def WoodRayNumSlices() -> str: ...
    @property
    def WoodRayEllipseRadiusX() -> str: ...
    @property
    def WoodRayEllipseZ2x() -> str: ...
    @property
    def WoodFiberRoughness() -> str: ...
    @property
    def WoodDiffuseLobeWeight() -> str: ...
    @property
    def WoodUseLatewoodBump() -> str: ...
    @property
    def WoodLatewoodBumpDepth() -> str: ...
    @property
    def WoodUseGrooveRoughness() -> str: ...
    @property
    def WoodGrooveRoughness() -> str: ...
    @property
    def WoodFiberPerlinEnable() -> str: ...
    @property
    def WoodFiberPerlinProf() -> str: ...
    @property
    def WoodFiberPerlinScaleZ() -> str: ...
    @property
    def WoodFiberCosineEnable() -> str: ...
    @property
    def WoodFiberCosineProf() -> str: ...
    @property
    def WoodGrowthPerlinEnable() -> str: ...
    @property
    def WoodGrowthPerlinProf() -> str: ...
    @property
    def WoodDiffusePerlinEnable() -> str: ...
    @property
    def WoodDiffusePerlinProf() -> str: ...
    @property
    def WoodDiffusePerlinScaleZ() -> str: ...
    @property
    def WoodSecondaryPerlinEnable() -> str: ...
    @property
    def WoodSecondaryPerlinProf() -> str: ...
    @property
    def WoodSecondaryPerlinScaleZ() -> str: ...
    @property
    def WoodEarlycolorPerlinEnable() -> str: ...
    @property
    def WoodEarlycolorPerlinProf() -> str: ...
    @property
    def WoodLatecolorPerlinEnable() -> str: ...
    @property
    def WoodLatecolorPerlinProf() -> str: ...
    @property
    def WoodCurlyDistortionEnable() -> str: ...
    @property
    def WoodCurlyDistortionScale() -> str: ...
    @property
    def WoodCurlyDistortionMap() -> str: ...


class AppearanceAssetEditScope:
    def __init__(self, document: Document): ...
    @property
    def IsActive(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Start(self, assetElementId: ElementId) -> Asset: ...
    def Cancel(self) -> None: ...
    def Commit(self, updateOpenViews: bool) -> None: ...
    def Dispose(self) -> None: ...


class LayeredNdfType:
    Beckmann = 0
    Ggx = 1


class SurfaceNdfType:
    Beckmann = 0
    Ggx = 1


class WoodPoreType:
    InBothWoods = 0
    EarlywoodOnly = 1
    LatewoodOnly = 2


class CeramicType:
    Ceramic = 0
    Porcelain = 1


class CeramicApplicationType:
    HighGlossy = 0
    Satin = 1
    Matte = 2


class CeramicBumpType:
    #None = 0
    Wavy = 1
    Custom = 2


class CeramicPatternType:
    #None = 0
    Custom = 1


class CommonSharedAssetType:
    Shared = 0
    Independent = 1


class ConcreteSealantType:
    #None = 0
    Epoxy = 1
    Acrylic = 2


class ConcreteFinishType:
    Straight = 0
    Curved = 1
    Smooth = 2
    Polished = 3
    Custom = 4


class ConcreteBrightmodeType:
    #None = 0
    Automatic = 1
    Custom = 2


class GlazingTransmittanceColorType:
    Clear = 0
    Green = 1
    Gray = 2
    Blue = 3
    Bluegreen = 4
    Bronze = 5
    Custom = 6


class HardwoodTintEnabledType:
    NoColor = 0
    ColorChoice = 1


class HardwoodFinishType:
    Gloss = 0
    Semigloss = 1
    Satin = 2
    Unfinished = 3


class HardwoodApplicationType:
    looring = 0
    urniture = 1


class HardwoodImperfectionsType:
    #None = 0
    Automatic = 1
    Custom = 2


class MasonryCMUType:
    Cmu = 0
    Masonry = 1


class MasonryCMUApplicationType:
    Glossy = 0
    Matte = 1
    Unfinished = 2


class MasonryCMUPatternType:
    #None = 0
    Custom = 1


class MetalType:
    Aluminum = 0
    GalvanizedAlu = 1
    Chrome = 2
    Copper = 3
    Brass = 4
    Bronze = 5
    StainlessSteel = 6
    Zinc = 7


class MetalFinishType:
    Polished = 0
    SemiPolished = 1
    Satin = 2
    Brushed = 3


class MetalPatternType:
    #None = 0
    Knurl = 1
    DiamondPlate = 2
    CheckerPlate = 3
    Custom = 4


class MetalPerforationsType:
    #None = 0
    CirclesStaggered = 1
    CirclesStraight = 2
    Squares = 3
    Grecian = 4
    Cloverleaf = 5
    Hexagon = 6
    Custom = 7


class MetallicpaintFlecksType:
    #None = 0
    Enable = 1


class MetallicpaintPearlType:
    #None = 0
    Chromatic = 1
    Custom = 2


class MetallicpaintTopcoatType:
    Carpaint = 0
    Chrome = 1
    Matte = 2
    Custom = 3


class MetallicpaintFinishType:
    Smooth = 0
    Peeling = 1


class PlasticvinylType:
    Plasticsolid = 0
    Plastictransparent = 1
    Vinyl = 2


class PlasticvinylApplicationType:
    Polished = 0
    Glossy = 1
    Matte = 2


class PlasticvinylBumpType:
    #None = 0
    Custom = 1


class PlasticvinylPatternType:
    #None = 0
    Custom = 1


class SolidglassTransmittanceType:
    Clear = 0
    Green = 1
    Gray = 2
    Blue = 3
    Bluegreen = 4
    Bronze = 5
    CustomColor = 6


class SolidglassBumpEnableType:
    #None = 0
    Rippled = 1
    Wavy = 2
    Custom = 3


class StoneApplicationType:
    Polished = 0
    Glossy = 1
    Matte = 2
    Unfinished = 3


class StoneBumpType:
    #None = 0
    Polishedgranite = 1
    Stonewall = 2
    Glossymarble = 3
    Custom = 4


class StonePatternType:
    #None = 0
    Custom = 1


class WallpaintFinishType:
    Flat = 0
    Eggshell = 1
    Platinum = 2
    Pearl = 3
    Semigloss = 4
    Gloss = 5


class WallpaintApplicationType:
    Roller = 0
    Brush = 1
    Spray = 2


class WaterType:
    SwimmingPool = 0
    ReflectingPool = 1
    River = 2
    Lake = 3
    Ocean = 4


class WaterTintEnableType:
    Tropical = 0
    Algae = 1
    Murky = 2
    ReflectingPool = 3
    River = 4
    Lake = 5
    Ocean = 6
    Custom = 7


class BumpmapType:
    HeightMap = 0
    NormalMap = 1


class GradientInterpolationType:
    Custom = 0
    Easein = 1
    Easeinout = 2
    Easeout = 3
    Linear = 4
    Solid = 5


class GradientNoiseType:
    Regular = 0
    Turbulence = 1
    Fractal = 2


class GradientType:
    Fourcorner = 0
    Box = 1
    Diagonal = 2
    Lighting = 3
    Linear = 4
    Mapped = 5
    Normal = 6
    Pong = 7
    Radial = 8
    Spiral = 9
    Sweep = 10
    Tartan = 11


class NoiseType:
    Regular = 0
    Fractal = 1
    Turbulence = 2


class TileBrickType:
    RunningBond = 0
    CommonFlemishBond = 1
    EnglishBond = 2
    HalfRunningBond = 3
    StackBond = 4
    FineRunningBond = 5
    FineStackBond = 6
    Custom = 7


class WaveDistributionType:
    TwoD = 0
    ThreeD = 1


class BumpMap:
    @property
    def BumpmapBitmap() -> str: ...
    @property
    def TextureLinkTextureTransforms() -> str: ...
    @property
    def TextureRealWorldOffsetX() -> str: ...
    @property
    def TextureRealWorldOffsetY() -> str: ...
    @property
    def TextureOffsetLock() -> str: ...
    @property
    def TextureWAngle() -> str: ...
    @property
    def TextureRealWorldScaleX() -> str: ...
    @property
    def TextureRealWorldScaleY() -> str: ...
    @property
    def TextureScaleLock() -> str: ...
    @property
    def BumpmapDepth() -> str: ...
    @property
    def BumpmapNormalScale() -> str: ...
    @property
    def TextureURepeat() -> str: ...
    @property
    def TextureVRepeat() -> str: ...
    @property
    def BumpmapType() -> str: ...


class Ceramic:
    @property
    def CeramicType() -> str: ...
    @property
    def CeramicColor() -> str: ...
    @property
    def CeramicColorByObject() -> str: ...
    @property
    def CeramicApplication() -> str: ...
    @property
    def CeramicBump() -> str: ...
    @property
    def CeramicBumpMap() -> str: ...
    @property
    def CeramicBumpAmount() -> str: ...
    @property
    def CeramicPattern() -> str: ...
    @property
    def CeramicPatternMap() -> str: ...
    @property
    def CeramicPatternAmount() -> str: ...
    @property
    def CommonTintToggle() -> str: ...
    @property
    def CommonTintColor() -> str: ...


class Checker:
    @property
    def CheckerColor1() -> str: ...
    @property
    def CheckerColor2() -> str: ...
    @property
    def CheckerSoften() -> str: ...
    @property
    def TextureLinkTextureTransforms() -> str: ...
    @property
    def TextureRealWorldOffsetX() -> str: ...
    @property
    def TextureRealWorldOffsetY() -> str: ...
    @property
    def TextureOffsetLock() -> str: ...
    @property
    def TextureWAngle() -> str: ...
    @property
    def TextureRealWorldScaleX() -> str: ...
    @property
    def TextureRealWorldScaleY() -> str: ...
    @property
    def TextureScaleLock() -> str: ...
    @property
    def TextureURepeat() -> str: ...
    @property
    def TextureVRepeat() -> str: ...


class SchemaCommon:
    @property
    def Hidden() -> str: ...
    @property
    def VersionGUID() -> str: ...
    @property
    def BaseSchema() -> str: ...
    @property
    def Thumbnail() -> str: ...
    @property
    def Description() -> str: ...
    @property
    def UIName() -> str: ...
    @property
    def Keyword() -> str: ...
    @property
    def Category() -> str: ...


class Concrete:
    @property
    def ConcreteColor() -> str: ...
    @property
    def ConcreteSealant() -> str: ...
    @property
    def ConcreteFinish() -> str: ...
    @property
    def ConcreteBumpMap() -> str: ...
    @property
    def ConcreteBumpAmount() -> str: ...
    @property
    def ConcreteBrightmode() -> str: ...
    @property
    def ConcreteBmMap() -> str: ...
    @property
    def CommonTintToggle() -> str: ...
    @property
    def CommonTintColor() -> str: ...


class Generic:
    @property
    def GenericDiffuse() -> str: ...
    @property
    def ColorByObject() -> str: ...
    @property
    def GenericDiffuseImageFade() -> str: ...
    @property
    def GenericGlossiness() -> str: ...
    @property
    def GenericIsMetal() -> str: ...
    @property
    def GenericReflectivityAt0deg() -> str: ...
    @property
    def GenericReflectivityAt90deg() -> str: ...
    @property
    def GenericTransparency() -> str: ...
    @property
    def GenericTransparencyImageFade() -> str: ...
    @property
    def GenericRefractionTranslucencyWeight() -> str: ...
    @property
    def GenericRefractionIndex() -> str: ...
    @property
    def GenericCutoutOpacity() -> str: ...
    @property
    def GenericSelfIllumFilterMap() -> str: ...
    @property
    def GenericSelfIllumLuminance() -> str: ...
    @property
    def GenericSelfIllumColorTemperature() -> str: ...
    @property
    def GenericBumpMap() -> str: ...
    @property
    def GenericBumpAmount() -> str: ...
    @property
    def CommonTintToggle() -> str: ...
    @property
    def CommonTintColor() -> str: ...


class Glazing:
    @property
    def GlazingTransmittanceColor() -> str: ...
    @property
    def GlazingTransmittanceMap() -> str: ...
    @property
    def GlazingColorByObject() -> str: ...
    @property
    def GlazingReflectance() -> str: ...
    @property
    def GlazingNoLevels() -> str: ...
    @property
    def CommonTintToggle() -> str: ...
    @property
    def CommonTintColor() -> str: ...


class Gradient:
    @property
    def GradientColor() -> str: ...
    @property
    def GradientInterpolation() -> str: ...
    @property
    def GradientNoise() -> str: ...
    @property
    def GradientNoiseAmount() -> str: ...
    @property
    def GradientNoiseHigh() -> str: ...
    @property
    def GradientNoiseLevels() -> str: ...
    @property
    def GradientNoiseLow() -> str: ...
    @property
    def GradientNoisePhase() -> str: ...
    @property
    def GradientNoiseSize() -> str: ...
    @property
    def GradientNoiseSmooth() -> str: ...
    @property
    def GradientPosition() -> str: ...
    @property
    def GradientType() -> str: ...
    @property
    def TextureLinkTextureTransforms() -> str: ...
    @property
    def TextureRealWorldOffsetX() -> str: ...
    @property
    def TextureRealWorldOffsetY() -> str: ...
    @property
    def TextureOffsetLock() -> str: ...
    @property
    def TextureWAngle() -> str: ...
    @property
    def TextureRealWorldScaleX() -> str: ...
    @property
    def TextureRealWorldScaleY() -> str: ...
    @property
    def TextureScaleLock() -> str: ...
    @property
    def TextureURepeat() -> str: ...
    @property
    def TextureVRepeat() -> str: ...


class Hardwood:
    @property
    def HardwoodColor() -> str: ...
    @property
    def HardwoodTintEnabled() -> str: ...
    @property
    def HardwoodTintColor() -> str: ...
    @property
    def HardwoodFinish() -> str: ...
    @property
    def HardwoodApplication() -> str: ...
    @property
    def HardwoodImperfections() -> str: ...
    @property
    def HardwoodImperfectionsShader() -> str: ...
    @property
    def HardwoodImperfectionsAmount() -> str: ...
    @property
    def CommonTintToggle() -> str: ...
    @property
    def CommonTintColor() -> str: ...


class Marble:
    @property
    def MarbleColor1() -> str: ...
    @property
    def MarbleColor2() -> str: ...
    @property
    def MarbleSize() -> str: ...
    @property
    def MarbleWidth() -> str: ...
    @property
    def TextureAngle() -> str: ...
    @property
    def TextureLinkTextureTransforms() -> str: ...
    @property
    def TextureRealWorldOffsetX() -> str: ...
    @property
    def TextureRealWorldOffsetY() -> str: ...
    @property
    def TextureRealWorldOffsetZ() -> str: ...


class MasonryCMU:
    @property
    def MasonryCMUType() -> str: ...
    @property
    def MasonryCMUColor() -> str: ...
    @property
    def MasonryCMUColorByObject() -> str: ...
    @property
    def MasonryCMUApplication() -> str: ...
    @property
    def MasonryCMUPattern() -> str: ...
    @property
    def MasonryCMUPatternMap() -> str: ...
    @property
    def MasonryCMUPatternHeight() -> str: ...
    @property
    def CommonTintToggle() -> str: ...
    @property
    def CommonTintColor() -> str: ...


class Metal:
    @property
    def MetalType() -> str: ...
    @property
    def MetalColor() -> str: ...
    @property
    def MetalPatina() -> str: ...
    @property
    def MetalFinish() -> str: ...
    @property
    def MetalPattern() -> str: ...
    @property
    def MetalPatternShader() -> str: ...
    @property
    def MetalPatternHeight() -> str: ...
    @property
    def MetalPatternScale() -> str: ...
    @property
    def MetalPerforations() -> str: ...
    @property
    def MetalPerforationsShader() -> str: ...
    @property
    def MetalPerforationsSize() -> str: ...
    @property
    def MetalPerforationsCenter() -> str: ...
    @property
    def CommonTintToggle() -> str: ...
    @property
    def CommonTintColor() -> str: ...


class MetallicPaint:
    @property
    def MetallicpaintBaseColor() -> str: ...
    @property
    def MetallicpaintBaseColorByObject() -> str: ...
    @property
    def MetallicpaintBaseHighlightspread() -> str: ...
    @property
    def MetallicpaintFlecks() -> str: ...
    @property
    def MetallicpaintFlecksColorByObject() -> str: ...
    @property
    def MetallicpaintFlecksColor() -> str: ...
    @property
    def MetallicpaintFlecksSize() -> str: ...
    @property
    def MetallicpaintPearl() -> str: ...
    @property
    def MetallicpaintPearlAmount() -> str: ...
    @property
    def MetallicpaintPearlColorByObject() -> str: ...
    @property
    def MetallicpaintPearlColor() -> str: ...
    @property
    def MetallicpaintPearlIor() -> str: ...
    @property
    def MetallicpaintTopcoat() -> str: ...
    @property
    def MetallicpaintTopcoatGlossy() -> str: ...
    @property
    def MetallicpaintTopcoatFalloff() -> str: ...
    @property
    def MetallicpaintFinish() -> str: ...
    @property
    def MetallicpaintFinishPeelamount() -> str: ...
    @property
    def CommonTintToggle() -> str: ...
    @property
    def CommonTintColor() -> str: ...


class Mirror:
    @property
    def MirrorTintcolor() -> str: ...
    @property
    def MirrorColorByObject() -> str: ...
    @property
    def CommonTintToggle() -> str: ...
    @property
    def CommonTintColor() -> str: ...


class Noise:
    @property
    def NoiseType() -> str: ...
    @property
    def NoiseColor1() -> str: ...
    @property
    def NoiseColor2() -> str: ...
    @property
    def NoiseThresholdHigh() -> str: ...
    @property
    def NoiseThresholdLow() -> str: ...
    @property
    def NoiseSize() -> str: ...
    @property
    def NoiseLevels() -> str: ...
    @property
    def NoisePhase() -> str: ...
    @property
    def TextureAngle() -> str: ...
    @property
    def TextureLinkTextureTransforms() -> str: ...
    @property
    def TextureRealWorldOffsetX() -> str: ...
    @property
    def TextureRealWorldOffsetY() -> str: ...
    @property
    def TextureRealWorldOffsetZ() -> str: ...


class PlasticVinyl:
    @property
    def PlasticvinylType() -> str: ...
    @property
    def PlasticvinylColor() -> str: ...
    @property
    def PlasticvinylColorByObject() -> str: ...
    @property
    def PlasticvinylApplication() -> str: ...
    @property
    def PlasticvinylBump() -> str: ...
    @property
    def PlasticvinylBumpMap() -> str: ...
    @property
    def PlasticvinylBumpAmount() -> str: ...
    @property
    def PlasticvinylPattern() -> str: ...
    @property
    def PlasticvinylPatternMap() -> str: ...
    @property
    def PlasticvinylPatternAmount() -> str: ...
    @property
    def CommonTintToggle() -> str: ...
    @property
    def CommonTintColor() -> str: ...


class SolidGlass:
    @property
    def SolidglassTransmittance() -> str: ...
    @property
    def SolidglassTransmittanceCustomColor() -> str: ...
    @property
    def SolidglassColorByObject() -> str: ...
    @property
    def SolidglassReflectance() -> str: ...
    @property
    def SolidglassRefractionIor() -> str: ...
    @property
    def SolidglassGlossiness() -> str: ...
    @property
    def SolidglassBumpEnable() -> str: ...
    @property
    def SolidglassBumpMap() -> str: ...
    @property
    def SolidglassBumpAmount() -> str: ...
    @property
    def CommonTintToggle() -> str: ...
    @property
    def CommonTintColor() -> str: ...


class Speckle:
    @property
    def SpeckleColor1() -> str: ...
    @property
    def SpeckleColor2() -> str: ...
    @property
    def SpeckleSize() -> str: ...
    @property
    def TextureLinkTextureTransforms() -> str: ...
    @property
    def TextureRealWorldOffsetX() -> str: ...
    @property
    def TextureRealWorldOffsetY() -> str: ...
    @property
    def TextureRealWorldOffsetZ() -> str: ...
    @property
    def TextureAngle() -> str: ...


class Stone:
    @property
    def StoneColor() -> str: ...
    @property
    def StoneApplication() -> str: ...
    @property
    def StoneBump() -> str: ...
    @property
    def StoneBumpMap() -> str: ...
    @property
    def StoneBumpAmount() -> str: ...
    @property
    def StonePattern() -> str: ...
    @property
    def StonePatternMap() -> str: ...
    @property
    def StonePatternAmount() -> str: ...
    @property
    def CommonTintToggle() -> str: ...
    @property
    def CommonTintColor() -> str: ...


class Tile:
    @property
    def TileBrickType() -> str: ...
    @property
    def TileHorizontalCount() -> str: ...
    @property
    def TileVerticalCount() -> str: ...
    @property
    def TileBrickColor() -> str: ...
    @property
    def TileColorVariance() -> str: ...
    @property
    def TileFadeVariance() -> str: ...
    @property
    def TileRandomSeed() -> str: ...
    @property
    def TileMortarColor() -> str: ...
    @property
    def TileHorizontalGap() -> str: ...
    @property
    def TileVerticalGap() -> str: ...
    @property
    def TileEdgeRoughness() -> str: ...
    @property
    def TileLineShift() -> str: ...
    @property
    def TileRandomShift() -> str: ...
    @property
    def TileUseRowEdit() -> str: ...
    @property
    def TilePerRow() -> str: ...
    @property
    def TileChangeRow() -> str: ...
    @property
    def TileUseColumnEdit() -> str: ...
    @property
    def TilePerColumn() -> str: ...
    @property
    def TileChangeColumn() -> str: ...
    @property
    def TextureLinkTextureTransforms() -> str: ...
    @property
    def TextureRealWorldOffsetX() -> str: ...
    @property
    def TextureRealWorldOffsetY() -> str: ...
    @property
    def TextureOffsetLock() -> str: ...
    @property
    def TextureWAngle() -> str: ...
    @property
    def TextureRealWorldScaleX() -> str: ...
    @property
    def TextureRealWorldScaleY() -> str: ...
    @property
    def TextureScaleLock() -> str: ...
    @property
    def TextureURepeat() -> str: ...
    @property
    def TextureVRepeat() -> str: ...


class UnifiedBitmap:
    @property
    def UnifiedbitmapBitmap() -> str: ...
    @property
    def UnifiedbitmapRGBAmount() -> str: ...
    @property
    def UnifiedbitmapInvert() -> str: ...
    @property
    def TextureLinkTextureTransforms() -> str: ...
    @property
    def TextureRealWorldOffsetX() -> str: ...
    @property
    def TextureRealWorldOffsetY() -> str: ...
    @property
    def TextureOffsetLock() -> str: ...
    @property
    def TextureWAngle() -> str: ...
    @property
    def TextureRealWorldScaleX() -> str: ...
    @property
    def TextureRealWorldScaleY() -> str: ...
    @property
    def TextureScaleLock() -> str: ...
    @property
    def TextureURepeat() -> str: ...
    @property
    def TextureVRepeat() -> str: ...


class WallPaint:
    @property
    def WallpaintColor() -> str: ...
    @property
    def WallpaintFinish() -> str: ...
    @property
    def WallpaintApplication() -> str: ...
    @property
    def CommonTintToggle() -> str: ...
    @property
    def CommonTintColor() -> str: ...


class Water:
    @property
    def WaterType() -> str: ...
    @property
    def WaterTintEnable() -> str: ...
    @property
    def WaterTintColor() -> str: ...
    @property
    def WaterColorByObject() -> str: ...
    @property
    def WaterBumpAmount() -> str: ...
    @property
    def CommonTintToggle() -> str: ...
    @property
    def CommonTintColor() -> str: ...


class Wave:
    @property
    def WaveColor1() -> str: ...
    @property
    def WaveColor2() -> str: ...
    @property
    def WaveDistribution() -> str: ...
    @property
    def WaveNumWaveSets() -> str: ...
    @property
    def WaveWaveRadius() -> str: ...
    @property
    def WaveWaveLenMin() -> str: ...
    @property
    def WaveWaveLenMax() -> str: ...
    @property
    def WaveAmplitude() -> str: ...
    @property
    def WavePhase() -> str: ...
    @property
    def WaveRandomSeed() -> str: ...
    @property
    def TextureLinkTextureTransforms() -> str: ...
    @property
    def TextureRealWorldOffsetX() -> str: ...
    @property
    def TextureRealWorldOffsetY() -> str: ...
    @property
    def TextureRealWorldOffsetZ() -> str: ...
    @property
    def TextureAngle() -> str: ...


class Wood:
    @property
    def WoodColor1() -> str: ...
    @property
    def WoodColor2() -> str: ...
    @property
    def WoodRadialNoise() -> str: ...
    @property
    def WoodAxialNoise() -> str: ...
    @property
    def WoodThickness() -> str: ...
    @property
    def TextureLinkTextureTransforms() -> str: ...
    @property
    def TextureRealWorldOffsetX() -> str: ...
    @property
    def TextureRealWorldOffsetY() -> str: ...
    @property
    def TextureRealWorldOffsetZ() -> str: ...
    @property
    def TextureAngle() -> str: ...



class RawSecurityDescriptor(GenericSecurityDescriptor):
 """
 Represents a security descriptor. A security descriptor includes an owner,a primary group,a Discretionary Access Control List (DACL),and a System Access Control List (SACL).

 

 RawSecurityDescriptor(flags: ControlFlags,owner: SecurityIdentifier,group: SecurityIdentifier,systemAcl: RawAcl,discretionaryAcl: RawAcl)

 RawSecurityDescriptor(sddlForm: str)

 RawSecurityDescriptor(binaryForm: Array[Byte],offset: int)
 """
 def SetFlags(self,flags):
  """
  SetFlags(self: RawSecurityDescriptor,flags: ControlFlags)

   Sets the System.Security.AccessControl.RawSecurityDescriptor.ControlFlags property of this 

    System.Security.AccessControl.RawSecurityDescriptor object to the specified value.

  

  

   flags: One or more values of the System.Security.AccessControl.ControlFlags enumeration combined with a 

    logical OR operation.
  """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,flags: ControlFlags,owner: SecurityIdentifier,group: SecurityIdentifier,systemAcl: RawAcl,discretionaryAcl: RawAcl)

  __new__(cls: type,sddlForm: str)

  __new__(cls: type,binaryForm: Array[Byte],offset: int)
  """
  pass
 ControlFlags=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets values that specify behavior of the System.Security.AccessControl.RawSecurityDescriptor object.



Get: ControlFlags(self: RawSecurityDescriptor) -> ControlFlags



"""

 DiscretionaryAcl=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the Discretionary Access Control List (DACL) for this System.Security.AccessControl.RawSecurityDescriptor object. The DACL contains access rules.



Get: DiscretionaryAcl(self: RawSecurityDescriptor) -> RawAcl



Set: DiscretionaryAcl(self: RawSecurityDescriptor)=value

"""

 Group=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the primary group for this System.Security.AccessControl.RawSecurityDescriptor object.



Get: Group(self: RawSecurityDescriptor) -> SecurityIdentifier



Set: Group(self: RawSecurityDescriptor)=value

"""

 Owner=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the owner of the object associated with this System.Security.AccessControl.RawSecurityDescriptor object.



Get: Owner(self: RawSecurityDescriptor) -> SecurityIdentifier



Set: Owner(self: RawSecurityDescriptor)=value

"""

 ResourceManagerControl=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a byte value that represents the resource manager control bits associated with this System.Security.AccessControl.RawSecurityDescriptor object.



Get: ResourceManagerControl(self: RawSecurityDescriptor) -> Byte



Set: ResourceManagerControl(self: RawSecurityDescriptor)=value

"""

 SystemAcl=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System Access Control List (SACL) for this System.Security.AccessControl.RawSecurityDescriptor object. The SACL contains audit rules.



Get: SystemAcl(self: RawSecurityDescriptor) -> RawAcl



Set: SystemAcl(self: RawSecurityDescriptor)=value

"""





"""Utility functions for managing pyRevit versions.

Examples:
        ```python
        from pyrevit import versionmgr
        v = versionmgr.get_pyrevit_version()
        v.get_formatted()
        ```
        '4.10-beta2'
"""
import os.path as op

from pyrevit import HOME_DIR, BIN_DIR
from pyrevit import VERSION_MAJOR, VERSION_MINOR, VERSION_PATCH, BUILD_METADATA
from pyrevit import PYREVIT_CLI_PATH
from pyrevit.compat import safe_strtype
from pyrevit import coreutils
from pyrevit.coreutils.logger import get_logger
from pyrevit.coreutils import envvars
from pyrevit.coreutils import git


#pylint: disable=W0703,C0302,C0103
mlogger = get_logger(__name__)


class _PyRevitVersion(object):
    """pyRevit version wrapper.

    Args:
        commit_hash (str): signature
    """
    major = VERSION_MAJOR
    minor = VERSION_MINOR
    patch = VERSION_PATCH
    metadata = BUILD_METADATA
    signature = ''

    def __init__(self, signature):
        self.signature = safe_strtype(signature)[:7]

    def as_int_tuple(self):
        """Returns version as an int tuple (major, minor, patch)."""
        try:
            signature = int(self.patch, 16)
        except Exception:
            signature = 0

        ver_tuple = (_PyRevitVersion.major, _PyRevitVersion.minor, signature)
        return ver_tuple

    def as_str_tuple(self):
        """Returns version as an string tuple ('major', 'minor', 'patch')."""
        ver_tuple = (safe_strtype(_PyRevitVersion.major),
                     safe_strtype(_PyRevitVersion.minor),
                     safe_strtype(self.patch))
        return ver_tuple

    def get_formatted(self, strict=False, extended=False):
        """Returns 'major.minor.patch' in string."""
        formatted_ver = '{}.{}.{}'.format(_PyRevitVersion.major,
                                          _PyRevitVersion.minor,
                                          _PyRevitVersion.patch)

        if not strict and self.metadata:
            formatted_ver += ('.' + self.metadata)

        if extended and not strict:
            formatted_ver += (':' + self.signature)

        return formatted_ver


def get_pyrevit_repo():
    """Return pyRevit repository.

    Returns:
        (pyrevit.coreutils.git.RepoInfo): repo wrapper object
    """
    try:
        return git.get_repo(HOME_DIR)
    except Exception as repo_err:
        mlogger.debug('Can not create repo from directory: %s | %s',
                      HOME_DIR, repo_err)


def get_pyrevit_version():
    """Return information about active pyRevit version.

    Returns:
        (_PyRevitVersion): version wrapper object
    """
    try:
        return _PyRevitVersion(get_pyrevit_repo().last_commit_hash)
    except Exception as ver_err:
        mlogger.debug('Can not get pyRevit patch number. | %s', ver_err)
        return _PyRevitVersion('')


def get_pyrevit_cli_version():
    """Return version of shipped pyRevit CLI utility.

    Returns:
        (str): version string of pyRevit CLI utility binary
    """
    return coreutils.get_exe_version(PYREVIT_CLI_PATH)



class ColumnWidthChangingEventArgs(CancelEventArgs):
 """
 Provides data for the System.Windows.Forms.ListView.ColumnWidthChanging event.

 

 ColumnWidthChangingEventArgs(columnIndex: int,newWidth: int,cancel: bool)

 ColumnWidthChangingEventArgs(columnIndex: int,newWidth: int)
 """
 @staticmethod
 def __new__(self,columnIndex,newWidth,cancel=None):
  """
  __new__(cls: type,columnIndex: int,newWidth: int,cancel: bool)

  __new__(cls: type,columnIndex: int,newWidth: int)
  """
  pass
 ColumnIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the index of the column whose width is changing.



Get: ColumnIndex(self: ColumnWidthChangingEventArgs) -> int



"""

 NewWidth=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the new width for the column.



Get: NewWidth(self: ColumnWidthChangingEventArgs) -> int



Set: NewWidth(self: ColumnWidthChangingEventArgs)=value

"""





class BindingSource(Component,IComponent,IDisposable,IBindingListView,IBindingList,IList,ICollection,IEnumerable,ITypedList,ICancelAddNew,ISupportInitializeNotification,ISupportInitialize,ICurrencyManagerProvider):
 """
 Encapsulates the data source for a form.

 

 BindingSource()

 BindingSource(dataSource: object,dataMember: str)

 BindingSource(container: IContainer)
 """
 def Add(self,value):
  """
  Add(self: BindingSource,value: object) -> int

  

   Adds an existing item to the internal list.

  

   value: An System.Object to be added to the internal list.

   Returns: The zero-based index at which value was added to the underlying list represented by the 

    System.Windows.Forms.BindingSource.List property.
  """
  pass
 def AddNew(self):
  """
  AddNew(self: BindingSource) -> object

  

   Adds a new item to the underlying list.

   Returns: The System.Object that was created and added to the list.
  """
  pass
 def ApplySort(self,*__args):
  """
  ApplySort(self: BindingSource,sorts: ListSortDescriptionCollection)

   Sorts the data source with the specified sort descriptions.

  

   sorts: A System.ComponentModel.ListSortDescriptionCollection containing the sort descriptions to apply 

    to the data source.

  

  ApplySort(self: BindingSource,property: PropertyDescriptor,sort: ListSortDirection)

   Sorts the data source using the specified property descriptor and sort direction.

  

   property: A System.ComponentModel.PropertyDescriptor that describes the property by which to sort the data 

    source.

  

   sort: A System.ComponentModel.ListSortDirection indicating how the list should be sorted.
  """
  pass
 def CancelEdit(self):
  """
  CancelEdit(self: BindingSource)

   Cancels the current edit operation.
  """
  pass
 def Clear(self):
  """
  Clear(self: BindingSource)

   Removes all elements from the list.
  """
  pass
 def Contains(self,value):
  """
  Contains(self: BindingSource,value: object) -> bool

  

   Determines whether an object is an item in the list.

  

   value: The System.Object to locate in the underlying list represented by the 

    System.Windows.Forms.BindingSource.List property. The value can be null.

  

   Returns: true if the value parameter is found in the System.Windows.Forms.BindingSource.List; otherwise,

    false.
  """
  pass
 def CopyTo(self,arr,index):
  """
  CopyTo(self: BindingSource,arr: Array,index: int)

   Copies the contents of the System.Windows.Forms.BindingSource.List to the specified array,

    starting at the specified index value.

  

  

   arr: The destination array.

   index: The index in the destination array at which to start the copy operation.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: BindingSource,disposing: bool)

   Releases the unmanaged resources used by the System.Windows.Forms.BindingSource and optionally 

    releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def EndEdit(self):
  """
  EndEdit(self: BindingSource)

   Applies pending changes to the underlying data source.
  """
  pass
 def Find(self,*__args):
  """
  Find(self: BindingSource,prop: PropertyDescriptor,key: object) -> int

  

   Searches for the index of the item that has the given property descriptor.

  

   prop: The System.ComponentModel.PropertyDescriptor to search for.

   key: The value of prop to match.

   Returns: The zero-based index of the item that has the given value for 

    System.ComponentModel.PropertyDescriptor.

  

  Find(self: BindingSource,propertyName: str,key: object) -> int

  

   Returns the index of the item in the list with the specified property name and value.

  

   propertyName: The name of the property to search for.

   key: The value of the item with the specified propertyName to find.

   Returns: The zero-based index of the item with the specified property name and value.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: BindingSource) -> IEnumerator

  

   Retrieves an enumerator for the System.Windows.Forms.BindingSource.List.

   Returns: An System.Collections.IEnumerator for the System.Windows.Forms.BindingSource.List.
  """
  pass
 def GetItemProperties(self,listAccessors):
  """
  GetItemProperties(self: BindingSource,listAccessors: Array[PropertyDescriptor]) -> PropertyDescriptorCollection

  

   Retrieves an array of System.ComponentModel.PropertyDescriptor objects representing the bindable 

    properties of the data source list type.

  

  

   listAccessors: An array of System.ComponentModel.PropertyDescriptor objects to find in the list as bindable.

   Returns: An array of System.ComponentModel.PropertyDescriptor objects that represents the properties on 

    this list type used to bind data.
  """
  pass
 def GetListName(self,listAccessors):
  """
  GetListName(self: BindingSource,listAccessors: Array[PropertyDescriptor]) -> str

  

   Gets the name of the list supplying data for the binding.

  

   listAccessors: An array of System.ComponentModel.PropertyDescriptor objects to find in the list as bindable.

   Returns: The name of the list supplying the data for binding.
  """
  pass
 def GetRelatedCurrencyManager(self,dataMember):
  """
  GetRelatedCurrencyManager(self: BindingSource,dataMember: str) -> CurrencyManager

  

   Gets the related currency manager for the specified data member.

  

   dataMember: The name of column or list,within the data source to retrieve the currency manager for.

   Returns: The related System.Windows.Forms.CurrencyManager for the specified data member.
  """
  pass
 def GetService(self,*args):
  """
  GetService(self: Component,service: Type) -> object

  

   Returns an object that represents a service provided by the System.ComponentModel.Component or 

    by its System.ComponentModel.Container.

  

  

   service: A service provided by the System.ComponentModel.Component.

   Returns: An System.Object that represents a service provided by the System.ComponentModel.Component,or 

    null if the System.ComponentModel.Component does not provide the specified service.
  """
  pass
 def IndexOf(self,value):
  """
  IndexOf(self: BindingSource,value: object) -> int

  

   Searches for the specified object and returns the index of the first occurrence within the 

    entire list.

  

  

   value: The System.Object to locate in the underlying list represented by the 

    System.Windows.Forms.BindingSource.List property. The value can be null.

  

   Returns: The zero-based index of the first occurrence of the value parameter; otherwise,-1 if value is 

    not in the list.
  """
  pass
 def Insert(self,index,value):
  """
  Insert(self: BindingSource,index: int,value: object)

   Inserts an item into the list at the specified index.

  

   index: The zero-based index at which value should be inserted.

   value: The System.Object to insert. The value can be null.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def MoveFirst(self):
  """
  MoveFirst(self: BindingSource)

   Moves to the first item in the list.
  """
  pass
 def MoveLast(self):
  """
  MoveLast(self: BindingSource)

   Moves to the last item in the list.
  """
  pass
 def MoveNext(self):
  """
  MoveNext(self: BindingSource)

   Moves to the next item in the list.
  """
  pass
 def MovePrevious(self):
  """
  MovePrevious(self: BindingSource)

   Moves to the previous item in the list.
  """
  pass
 def OnAddingNew(self,*args):
  """
  OnAddingNew(self: BindingSource,e: AddingNewEventArgs)

   Raises the System.Windows.Forms.BindingSource.AddingNew event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnBindingComplete(self,*args):
  """
  OnBindingComplete(self: BindingSource,e: BindingCompleteEventArgs)

   Raises the System.Windows.Forms.BindingSource.BindingComplete event.

  

   e: A System.Windows.Forms.BindingCompleteEventArgs  that contains the event data.
  """
  pass
 def OnCurrentChanged(self,*args):
  """
  OnCurrentChanged(self: BindingSource,e: EventArgs)

   Raises the System.Windows.Forms.BindingSource.CurrentChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnCurrentItemChanged(self,*args):
  """
  OnCurrentItemChanged(self: BindingSource,e: EventArgs)

   Raises the System.Windows.Forms.BindingSource.CurrentItemChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnDataError(self,*args):
  """
  OnDataError(self: BindingSource,e: BindingManagerDataErrorEventArgs)

   Raises the System.Windows.Forms.BindingSource.DataError event.

  

   e: A System.Windows.Forms.BindingManagerDataErrorEventArgs that contains the event data.
  """
  pass
 def OnDataMemberChanged(self,*args):
  """
  OnDataMemberChanged(self: BindingSource,e: EventArgs)

   Raises the System.Windows.Forms.BindingSource.DataMemberChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnDataSourceChanged(self,*args):
  """
  OnDataSourceChanged(self: BindingSource,e: EventArgs)

   Raises the System.Windows.Forms.BindingSource.DataSourceChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnListChanged(self,*args):
  """
  OnListChanged(self: BindingSource,e: ListChangedEventArgs)

   Raises the System.Windows.Forms.BindingSource.ListChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnPositionChanged(self,*args):
  """
  OnPositionChanged(self: BindingSource,e: EventArgs)

   Raises the System.Windows.Forms.BindingSource.PositionChanged event.

  

   e: A System.ComponentModel.ListChangedEventArgs that contains the event data.
  """
  pass
 def Remove(self,value):
  """
  Remove(self: BindingSource,value: object)

   Removes the specified item from the list.

  

   value: The item to remove from the underlying list represented by the 

    System.Windows.Forms.BindingSource.List property.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: BindingSource,index: int)

   Removes the item at the specified index in the list.

  

   index: The zero-based index of the item to remove.
  """
  pass
 def RemoveCurrent(self):
  """
  RemoveCurrent(self: BindingSource)

   Removes the current item from the list.
  """
  pass
 def RemoveFilter(self):
  """
  RemoveFilter(self: BindingSource)

   Removes the filter associated with the System.Windows.Forms.BindingSource.
  """
  pass
 def RemoveSort(self):
  """
  RemoveSort(self: BindingSource)

   Removes the sort associated with the System.Windows.Forms.BindingSource.
  """
  pass
 def ResetAllowNew(self):
  """
  ResetAllowNew(self: BindingSource)

   Reinitializes the System.Windows.Forms.BindingSource.AllowNew property.
  """
  pass
 def ResetBindings(self,metadataChanged):
  """
  ResetBindings(self: BindingSource,metadataChanged: bool)

   Causes a control bound to the System.Windows.Forms.BindingSource to reread all the items in the 

    list and refresh their displayed values.

  

  

   metadataChanged: true if the data schema has changed; false if only values have changed.
  """
  pass
 def ResetCurrentItem(self):
  """
  ResetCurrentItem(self: BindingSource)

   Causes a control bound to the System.Windows.Forms.BindingSource to reread the currently 

    selected item and refresh its displayed value.
  """
  pass
 def ResetItem(self,itemIndex):
  """
  ResetItem(self: BindingSource,itemIndex: int)

   Causes a control bound to the System.Windows.Forms.BindingSource to reread the item at the 

    specified index,and refresh its displayed value.

  

  

   itemIndex: The zero-based index of the item that has changed.
  """
  pass
 def ResumeBinding(self):
  """
  ResumeBinding(self: BindingSource)

   Resumes data binding.
  """
  pass
 def SuspendBinding(self):
  """
  SuspendBinding(self: BindingSource)

   Suspends data binding to prevent changes from updating the bound data source.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: IList,value: object) -> bool

  

   Determines whether the System.Collections.IList contains a specific value.

  

   value: The object to locate in the System.Collections.IList.

   Returns: true if the System.Object is found in the System.Collections.IList; otherwise,false.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,dataSource: object,dataMember: str)

  __new__(cls: type,container: IContainer)
  """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 def __str__(self,*args):
  pass
 AllowEdit=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether items in the underlying list can be edited.



Get: AllowEdit(self: BindingSource) -> bool



"""

 AllowNew=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the System.Windows.Forms.BindingSource.AddNew method can be used to add items to the list.



Get: AllowNew(self: BindingSource) -> bool



Set: AllowNew(self: BindingSource)=value

"""

 AllowRemove=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether items can be removed from the underlying list.



Get: AllowRemove(self: BindingSource) -> bool



"""

 CanRaiseEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component can raise an event.



"""

 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the total number of items in the underlying list,taking the current System.Windows.Forms.BindingSource.Filter value into consideration.



Get: Count(self: BindingSource) -> int



"""

 CurrencyManager=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the currency manager associated with this System.Windows.Forms.BindingSource.



Get: CurrencyManager(self: BindingSource) -> CurrencyManager



"""

 Current=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the current item in the list.



Get: Current(self: BindingSource) -> object



"""

 DataMember=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the specific list in the data source to which the connector currently binds to.



Get: DataMember(self: BindingSource) -> str



Set: DataMember(self: BindingSource)=value

"""

 DataSource=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the data source that the connector binds to.



Get: DataSource(self: BindingSource) -> object



Set: DataSource(self: BindingSource)=value

"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.ComponentModel.Component is currently in design mode.



"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this System.ComponentModel.Component.



"""

 Filter=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the expression used to filter which rows are viewed.



Get: Filter(self: BindingSource) -> str



Set: Filter(self: BindingSource)=value

"""

 IsBindingSuspended=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the list binding is suspended.



Get: IsBindingSuspended(self: BindingSource) -> bool



"""

 IsFixedSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the underlying list has a fixed size.



Get: IsFixedSize(self: BindingSource) -> bool



"""

 IsReadOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the underlying list is read-only.



Get: IsReadOnly(self: BindingSource) -> bool



"""

 IsSorted=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the items in the underlying list are sorted.



Get: IsSorted(self: BindingSource) -> bool



"""

 IsSynchronized=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether access to the collection is synchronized (thread safe).



Get: IsSynchronized(self: BindingSource) -> bool



"""

 List=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list that the connector is bound to.



Get: List(self: BindingSource) -> IList



"""

 Position=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the index of the current item in the underlying list.



Get: Position(self: BindingSource) -> int



Set: Position(self: BindingSource)=value

"""

 RaiseListChangedEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether System.Windows.Forms.BindingSource.ListChanged events should be raised.



Get: RaiseListChangedEvents(self: BindingSource) -> bool



Set: RaiseListChangedEvents(self: BindingSource)=value

"""

 Sort=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the column names used for sorting,and the sort order for viewing the rows in the data source.



Get: Sort(self: BindingSource) -> str



Set: Sort(self: BindingSource)=value

"""

 SortDescriptions=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of sort descriptions applied to the data source.



Get: SortDescriptions(self: BindingSource) -> ListSortDescriptionCollection



"""

 SortDirection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the direction the items in the list are sorted.



Get: SortDirection(self: BindingSource) -> ListSortDirection



"""

 SortProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.ComponentModel.PropertyDescriptor that is being used for sorting the list.



Get: SortProperty(self: BindingSource) -> PropertyDescriptor



"""

 SupportsAdvancedSorting=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the data source supports multi-column sorting.



Get: SupportsAdvancedSorting(self: BindingSource) -> bool



"""

 SupportsChangeNotification=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the data source supports change notification.



Get: SupportsChangeNotification(self: BindingSource) -> bool



"""

 SupportsFiltering=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the data source supports filtering.



Get: SupportsFiltering(self: BindingSource) -> bool



"""

 SupportsSearching=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the data source supports searching with the System.Windows.Forms.BindingSource.Find(System.ComponentModel.PropertyDescriptor,System.Object) method.



Get: SupportsSearching(self: BindingSource) -> bool



"""

 SupportsSorting=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the data source supports sorting.



Get: SupportsSorting(self: BindingSource) -> bool



"""

 SyncRoot=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an object that can be used to synchronize access to the underlying list.



Get: SyncRoot(self: BindingSource) -> object



"""


 AddingNew=None
 BindingComplete=None
 CurrentChanged=None
 CurrentItemChanged=None
 DataError=None
 DataMemberChanged=None
 DataSourceChanged=None
 ListChanged=None
 PositionChanged=None




class RefreshEventArgs(EventArgs):
 """
 Provides data for the System.ComponentModel.TypeDescriptor.Refreshed event.

 

 RefreshEventArgs(componentChanged: object)

 RefreshEventArgs(typeChanged: Type)
 """
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,componentChanged: object)

  __new__(cls: type,typeChanged: Type)
  """
  pass
 ComponentChanged=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the component that changed its properties,events,or extenders.



Get: ComponentChanged(self: RefreshEventArgs) -> object



"""

 TypeChanged=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Type that changed its properties or events.



Get: TypeChanged(self: RefreshEventArgs) -> Type



"""





class ContainerFilterService(object):
 """ Provides a base class for the container filter service. """
 def FilterComponents(self,components):
  """
  FilterComponents(self: ContainerFilterService,components: ComponentCollection) -> ComponentCollection

  

   Filters the component collection.

  

   components: The component collection to filter.

   Returns: A System.ComponentModel.ComponentCollection that represents a modified collection.
  """
  pass



class ListViewInsertionMark(object):
 """ Used to indicate the expected drop location when an item is dragged to a new position in a System.Windows.Forms.ListView control. This functionality is available only on Windows XP and later. """
 def NearestIndex(self,pt):
  """
  NearestIndex(self: ListViewInsertionMark,pt: Point) -> int

  

   Retrieves the index of the item closest to the specified point.

  

   pt: A System.Drawing.Point representing the location from which to find the nearest item.

   Returns: The index of the item closest to the specified point or -1 if the closest item is the item 

    currently being dragged.
  """
  pass
 AppearsAfterItem=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the insertion mark appears to the right of the item with the index specified by the System.Windows.Forms.ListViewInsertionMark.Index property.



Get: AppearsAfterItem(self: ListViewInsertionMark) -> bool



Set: AppearsAfterItem(self: ListViewInsertionMark)=value

"""

 Bounds=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the bounding rectangle of the insertion mark.



Get: Bounds(self: ListViewInsertionMark) -> Rectangle



"""

 Color=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the color of the insertion mark.



Get: Color(self: ListViewInsertionMark) -> Color



Set: Color(self: ListViewInsertionMark)=value

"""

 Index=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the index of the item next to which the insertion mark appears.



Get: Index(self: ListViewInsertionMark) -> int



Set: Index(self: ListViewInsertionMark)=value

"""





class Color(object):
 """ Represents an ARGB (alpha,red,green,blue) color. """
 def Equals(self,obj):
  """
  Equals(self: Color,obj: object) -> bool

  

   Tests whether the specified object is a System.Drawing.Color structure and is equivalent to this 

    System.Drawing.Color structure.

  

  

   obj: The object to test.

   Returns: true if obj is a System.Drawing.Color structure equivalent to this System.Drawing.Color 

    structure; otherwise,false.
  """
  pass
 @staticmethod
 def FromArgb(*__args):
  """
  FromArgb(alpha: int,baseColor: Color) -> Color

  

   Creates a System.Drawing.Color structure from the specified System.Drawing.Color structure,but 

    with the new specified alpha value. Although this method allows a 32-bit value to be passed for 

    the alpha value,the value is limited to 8 bits.

  

  

   alpha: The alpha value for the new System.Drawing.Color. Valid values are 0 through 255.

   baseColor: The System.Drawing.Color from which to create the new System.Drawing.Color.

   Returns: The System.Drawing.Color that this method creates.

  FromArgb(red: int,green: int,blue: int) -> Color

  

   Creates a System.Drawing.Color structure from the specified 8-bit color values (red,green,and 

    blue). The alpha value is implicitly 255 (fully opaque). Although this method allows a 32-bit 

    value to be passed for each color component,the value of each component is limited to 8 bits.

  

  

   red: The red component value for the new System.Drawing.Color. Valid values are 0 through 255.

   green: The green component value for the new System.Drawing.Color. Valid values are 0 through 255.

   blue: The blue component value for the new System.Drawing.Color. Valid values are 0 through 255.

   Returns: The System.Drawing.Color that this method creates.

  FromArgb(argb: int) -> Color

  

   Creates a System.Drawing.Color structure from a 32-bit ARGB value.

  

   argb: A value specifying the 32-bit ARGB value.

   Returns: The System.Drawing.Color structure that this method creates.

  FromArgb(alpha: int,red: int,green: int,blue: int) -> Color

  

   Creates a System.Drawing.Color structure from the four ARGB component (alpha,red,green,and 

    blue) values. Although this method allows a 32-bit value to be passed for each component,the 

    value of each component is limited to 8 bits.

  

  

   alpha: The alpha component. Valid values are 0 through 255.

   red: The red component. Valid values are 0 through 255.

   green: The green component. Valid values are 0 through 255.

   blue: The blue component. Valid values are 0 through 255.

   Returns: The System.Drawing.Color that this method creates.
  """
  pass
 @staticmethod
 def FromKnownColor(color):
  """
  FromKnownColor(color: KnownColor) -> Color

  

   Creates a System.Drawing.Color structure from the specified predefined color.

  

   color: An element of the System.Drawing.KnownColor enumeration.

   Returns: The System.Drawing.Color that this method creates.
  """
  pass
 @staticmethod
 def FromName(name):
  """
  FromName(name: str) -> Color

  

   Creates a System.Drawing.Color structure from the specified name of a predefined color.

  

   name: A string that is the name of a predefined color. Valid names are the same as the names of the 

    elements of the System.Drawing.KnownColor enumeration.

  

   Returns: The System.Drawing.Color that this method creates.
  """
  pass
 def GetBrightness(self):
  """
  GetBrightness(self: Color) -> Single

  

   Gets the hue-saturation-brightness (HSB) brightness value for this System.Drawing.Color 

    structure.

  

   Returns: The brightness of this System.Drawing.Color. The brightness ranges from 0.0 through 1.0,where 

    0.0 represents black and 1.0 represents white.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: Color) -> int

  

   Returns a hash code for this System.Drawing.Color structure.

   Returns: An integer value that specifies the hash code for this System.Drawing.Color.
  """
  pass
 def GetHue(self):
  """
  GetHue(self: Color) -> Single

  

   Gets the hue-saturation-brightness (HSB) hue value,in degrees,for this System.Drawing.Color 

    structure.

  

   Returns: The hue,in degrees,of this System.Drawing.Color. The hue is measured in degrees,ranging from 

    0.0 through 360.0,in HSB color space.
  """
  pass
 def GetSaturation(self):
  """
  GetSaturation(self: Color) -> Single

  

   Gets the hue-saturation-brightness (HSB) saturation value for this System.Drawing.Color 

    structure.

  

   Returns: The saturation of this System.Drawing.Color. The saturation ranges from 0.0 through 1.0,where 

    0.0 is grayscale and 1.0 is the most saturated.
  """
  pass
 def ToArgb(self):
  """
  ToArgb(self: Color) -> int

  

   Gets the 32-bit ARGB value of this System.Drawing.Color structure.

   Returns: The 32-bit ARGB value of this System.Drawing.Color.
  """
  pass
 def ToKnownColor(self):
  """
  ToKnownColor(self: Color) -> KnownColor

  

   Gets the System.Drawing.KnownColor value of this System.Drawing.Color structure.

   Returns: An element of the System.Drawing.KnownColor enumeration,if the System.Drawing.Color is created 

    from a predefined color by using either the System.Drawing.Color.FromName(System.String) method 

    or the System.Drawing.Color.FromKnownColor(System.Drawing.KnownColor) method; otherwise,0.
  """
  pass
 def ToString(self):
  """
  ToString(self: Color) -> str

  

   Converts this System.Drawing.Color structure to a human-readable string.

   Returns: A string that is the name of this System.Drawing.Color,if the System.Drawing.Color is created 

    from a predefined color by using either the System.Drawing.Color.FromName(System.String) method 

    or the System.Drawing.Color.FromKnownColor(System.Drawing.KnownColor) method; otherwise,a 

    string that consists of the ARGB component names and their values.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __ne__(self,*args):
  pass
 A=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the alpha component value of this System.Drawing.Color structure.



Get: A(self: Color) -> Byte



"""

 B=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the blue component value of this System.Drawing.Color structure.



Get: B(self: Color) -> Byte



"""

 G=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the green component value of this System.Drawing.Color structure.



Get: G(self: Color) -> Byte



"""

 IsEmpty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Specifies whether this System.Drawing.Color structure is uninitialized.



Get: IsEmpty(self: Color) -> bool



"""

 IsKnownColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether this System.Drawing.Color structure is a predefined color. Predefined colors are represented by the elements of the System.Drawing.KnownColor enumeration.



Get: IsKnownColor(self: Color) -> bool



"""

 IsNamedColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether this System.Drawing.Color structure is a named color or a member of the System.Drawing.KnownColor enumeration.



Get: IsNamedColor(self: Color) -> bool



"""

 IsSystemColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether this System.Drawing.Color structure is a system color. A system color is a color that is used in a Windows display element. System colors are represented by elements of the System.Drawing.KnownColor enumeration.



Get: IsSystemColor(self: Color) -> bool



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of this System.Drawing.Color.



Get: Name(self: Color) -> str



"""

 R=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the red component value of this System.Drawing.Color structure.



Get: R(self: Color) -> Byte



"""


 AliceBlue=None
 AntiqueWhite=None
 Aqua=None
 Aquamarine=None
 Azure=None
 Beige=None
 Bisque=None
 Black=None
 BlanchedAlmond=None
 Blue=None
 BlueViolet=None
 Brown=None
 BurlyWood=None
 CadetBlue=None
 Chartreuse=None
 Chocolate=None
 Coral=None
 CornflowerBlue=None
 Cornsilk=None
 Crimson=None
 Cyan=None
 DarkBlue=None
 DarkCyan=None
 DarkGoldenrod=None
 DarkGray=None
 DarkGreen=None
 DarkKhaki=None
 DarkMagenta=None
 DarkOliveGreen=None
 DarkOrange=None
 DarkOrchid=None
 DarkRed=None
 DarkSalmon=None
 DarkSeaGreen=None
 DarkSlateBlue=None
 DarkSlateGray=None
 DarkTurquoise=None
 DarkViolet=None
 DeepPink=None
 DeepSkyBlue=None
 DimGray=None
 DodgerBlue=None
 Empty=None
 Firebrick=None
 FloralWhite=None
 ForestGreen=None
 Fuchsia=None
 Gainsboro=None
 GhostWhite=None
 Gold=None
 Goldenrod=None
 Gray=None
 Green=None
 GreenYellow=None
 Honeydew=None
 HotPink=None
 IndianRed=None
 Indigo=None
 Ivory=None
 Khaki=None
 Lavender=None
 LavenderBlush=None
 LawnGreen=None
 LemonChiffon=None
 LightBlue=None
 LightCoral=None
 LightCyan=None
 LightGoldenrodYellow=None
 LightGray=None
 LightGreen=None
 LightPink=None
 LightSalmon=None
 LightSeaGreen=None
 LightSkyBlue=None
 LightSlateGray=None
 LightSteelBlue=None
 LightYellow=None
 Lime=None
 LimeGreen=None
 Linen=None
 Magenta=None
 Maroon=None
 MediumAquamarine=None
 MediumBlue=None
 MediumOrchid=None
 MediumPurple=None
 MediumSeaGreen=None
 MediumSlateBlue=None
 MediumSpringGreen=None
 MediumTurquoise=None
 MediumVioletRed=None
 MidnightBlue=None
 MintCream=None
 MistyRose=None
 Moccasin=None
 NavajoWhite=None
 Navy=None
 OldLace=None
 Olive=None
 OliveDrab=None
 Orange=None
 OrangeRed=None
 Orchid=None
 PaleGoldenrod=None
 PaleGreen=None
 PaleTurquoise=None
 PaleVioletRed=None
 PapayaWhip=None
 PeachPuff=None
 Peru=None
 Pink=None
 Plum=None
 PowderBlue=None
 Purple=None
 Red=None
 RosyBrown=None
 RoyalBlue=None
 SaddleBrown=None
 Salmon=None
 SandyBrown=None
 SeaGreen=None
 SeaShell=None
 Sienna=None
 Silver=None
 SkyBlue=None
 SlateBlue=None
 SlateGray=None
 Snow=None
 SpringGreen=None
 SteelBlue=None
 Tan=None
 Teal=None
 Thistle=None
 Tomato=None
 Transparent=None
 Turquoise=None
 Violet=None
 Wheat=None
 White=None
 WhiteSmoke=None
 Yellow=None
 YellowGreen=None




# encoding: utf-8
# module System.Windows.Markup.Primitives calls itself Primitives
# from PresentationFramework,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class MarkupWriter(object,IDisposable):
 """ Provides methods to write an object to XAML format. """
 def Dispose(self):
  """
  Dispose(self: MarkupWriter)

   Releases the resources used by the System.Windows.Markup.Primitives.MarkupWriter.
  """
  pass
 @staticmethod
 def GetMarkupObjectFor(instance,manager=None):
  """
  GetMarkupObjectFor(instance: object,manager: XamlDesignerSerializationManager) -> MarkupObject

  

   Creates an instance of a System.Windows.Markup.Primitives.MarkupObject from the specified object 

    and the specified serialization manager.

  

  

   instance: An object that will be the root of the serialized tree.

   manager: The serialization manager.

   Returns: A markup object that enables navigating through the tree of objects.

  GetMarkupObjectFor(instance: object) -> MarkupObject

  

   Creates an instance of a System.Windows.Markup.Primitives.MarkupObject from the specified object.

  

   instance: An object that will be the root of the serialized tree.

   Returns: A markup object that enables navigating through the tree of objects.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass




class SystemFonts(object):
 """ Specifies the fonts used to display text in Windows display elements. """
 @staticmethod
 def GetFontByName(systemFontName):
  """
  GetFontByName(systemFontName: str) -> Font

  

   Returns a font object that corresponds to the specified system font name.

  

   systemFontName: The name of the system font you need a font object for.

   Returns: A System.Drawing.Font if the specified name matches a value in System.Drawing.SystemFonts; 

    otherwise,null.
  """
  pass
 CaptionFont=None
 DefaultFont=None
 DialogFont=None
 IconTitleFont=None
 MenuFont=None
 MessageBoxFont=None
 SmallCaptionFont=None
 StatusFont=None




class Decimal(object,IFormattable,IComparable,IConvertible,IDeserializationCallback,IComparable[Decimal],IEquatable[Decimal]):
 """
 Represents a decimal number.

 

 Decimal(value: int)

 Decimal(value: UInt32)

 Decimal(value: Int64)

 Decimal(value: UInt64)

 Decimal(value: Single)

 Decimal(value: float)

 Decimal(bits: Array[int])

 Decimal(lo: int,mid: int,hi: int,isNegative: bool,scale: Byte)
 """
 @staticmethod
 def Add(d1,d2):
  """
  Add(d1: Decimal,d2: Decimal) -> Decimal

  

   Adds two specified System.Decimal values.

  

   d1: The first value to add.

   d2: The second value to add.

   Returns: The sum of d1 and d2.
  """
  pass
 @staticmethod
 def Ceiling(d):
  """
  Ceiling(d: Decimal) -> Decimal

  

   Returns the smallest integral value that is greater than or equal to the specified decimal 

    number.

  

  

   d: A decimal number.

   Returns: The smallest integral value that is greater than or equal to the d parameter. Note that this 

    method returns a System.Decimal instead of an integral type.
  """
  pass
 @staticmethod
 def Compare(d1,d2):
  """
  Compare(d1: Decimal,d2: Decimal) -> int

  

   Compares two specified System.Decimal values.

  

   d1: The first value to compare.

   d2: The second value to compare.

   Returns: A signed number indicating the relative values of d1 and d2.Return Value Meaning Less than zero 

    d1 is less than d2. Zero d1 and d2 are equal. Greater than zero d1 is greater than d2.
  """
  pass
 def CompareTo(self,value):
  """
  CompareTo(self: Decimal,value: Decimal) -> int

  

   Compares this instance to a specified System.Decimal object.

  

   value: The object to compare with this instance.

   Returns: A signed number indicating the relative values of this instance and value.Return Value Meaning 

    Less than zero This instance is less than value. Zero This instance is equal to value. Greater 

    than zero This instance is greater than value.

  

  CompareTo(self: Decimal,value: object) -> int

  

   Compares this instance to a specified System.Object.

  

   value: The object to compare with this instance,or null.

   Returns: A signed number indicating the relative values of this instance and value.Return Value Meaning 

    Less than zero This instance is less than value. Zero This instance is equal to value. Greater 

    than zero This instance is greater than value.-or- value is null.
  """
  pass
 @staticmethod
 def Divide(d1,d2):
  """
  Divide(d1: Decimal,d2: Decimal) -> Decimal

  

   Divides two specified System.Decimal values.

  

   d1: The dividend.

   d2: The divisor.

   Returns: The result of dividing d1 by d2.
  """
  pass
 def Equals(self,*__args):
  """
  Equals(d1: Decimal,d2: Decimal) -> bool

  

   Returns a value indicating whether two specified instances of System.Decimal represent the same 

    value.

  

  

   d1: The first value to compare.

   d2: The second value to compare.

   Returns: true if d1 and d2 are equal; otherwise,false.

  Equals(self: Decimal,value: Decimal) -> bool

  

   Returns a value indicating whether this instance and a specified System.Decimal object represent 

    the same value.

  

  

   value: An object to compare to this instance.

   Returns: true if value is equal to this instance; otherwise,false.

  Equals(self: Decimal,value: object) -> bool

  

   Returns a value indicating whether this instance and a specified System.Object represent the 

    same type and value.

  

  

   value: The object to compare with this instance.

   Returns: true if value is a System.Decimal and equal to this instance; otherwise,false.
  """
  pass
 @staticmethod
 def Floor(d):
  """
  Floor(d: Decimal) -> Decimal

  

   Rounds a specified System.Decimal number to the closest integer toward negative infinity.

  

   d: The value to round.

   Returns: If d has a fractional part,the next whole System.Decimal number toward negative infinity that 

    is less than d.-or- If d doesn't have a fractional part,d is returned unchanged.
  """
  pass
 @staticmethod
 def FromOACurrency(cy):
  """
  FromOACurrency(cy: Int64) -> Decimal

  

   Converts the specified 64-bit signed integer,which contains an OLE Automation Currency value,

    to the equivalent System.Decimal value.

  

  

   cy: An OLE Automation Currency value.

   Returns: A System.Decimal that contains the equivalent of cy.
  """
  pass
 @staticmethod
 def GetBits(d):
  """
  GetBits(d: Decimal) -> Array[int]

  

   Converts the value of a specified instance of System.Decimal to its equivalent binary 

    representation.

  

  

   d: The value to convert.

   Returns: A 32-bit signed integer array with four elements that contain the binary representation of d.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: Decimal) -> int

  

   Returns the hash code for this instance.

   Returns: A 32-bit signed integer hash code.
  """
  pass
 def GetTypeCode(self):
  """
  GetTypeCode(self: Decimal) -> TypeCode

  

   Returns the System.TypeCode for value type System.Decimal.

   Returns: The enumerated constant System.TypeCode.Decimal.
  """
  pass
 @staticmethod
 def Multiply(d1,d2):
  """
  Multiply(d1: Decimal,d2: Decimal) -> Decimal

  

   Multiplies two specified System.Decimal values.

  

   d1: The multiplicand.

   d2: The multiplier.

   Returns: The result of multiplying d1 and d2.
  """
  pass
 @staticmethod
 def Negate(d):
  """
  Negate(d: Decimal) -> Decimal

  

   Returns the result of multiplying the specified System.Decimal value by negative one.

  

   d: The value to negate.

   Returns: A decimal number with the value of d,but the opposite sign.-or- Zero,if d is zero.
  """
  pass
 @staticmethod
 def Parse(s,*__args):
  """
  Parse(s: str,provider: IFormatProvider) -> Decimal

  

   Converts the string representation of a number to its System.Decimal equivalent using the 

    specified culture-specific format information.

  

  

   s: The string representation of the number to convert.

   provider: An System.IFormatProvider that supplies culture-specific parsing information about s.

   Returns: The System.Decimal number equivalent to the number contained in s as specified by provider.

  Parse(s: str,style: NumberStyles,provider: IFormatProvider) -> Decimal

  

   Converts the string representation of a number to its System.Decimal equivalent using the 

    specified style and culture-specific format.

  

  

   s: The string representation of the number to convert.

   style: A bitwise combination of System.Globalization.NumberStyles values that indicates the style 

    elements that can be present in s. A typical value to specify is 

    System.Globalization.NumberStyles.Number.

  

   provider: An System.IFormatProvider object that supplies culture-specific information about the format of 

    s.

  

   Returns: The System.Decimal number equivalent to the number contained in s as specified by style and 

    provider.

  

  Parse(s: str) -> Decimal

  

   Converts the string representation of a number to its System.Decimal equivalent.

  

   s: The string representation of the number to convert.

   Returns: The equivalent to the number contained in s.

  Parse(s: str,style: NumberStyles) -> Decimal

  

   Converts the string representation of a number in a specified style to its System.Decimal 

    equivalent.

  

  

   s: The string representation of the number to convert.

   style: A bitwise combination of System.Globalization.NumberStyles values that indicates the style 

    elements that can be present in s. A typical value to specify is 

    System.Globalization.NumberStyles.Number.

  

   Returns: The System.Decimal number equivalent to the number contained in s as specified by style.
  """
  pass
 @staticmethod
 def Remainder(d1,d2):
  """
  Remainder(d1: Decimal,d2: Decimal) -> Decimal

  

   Computes the remainder after dividing two System.Decimal values.

  

   d1: The dividend.

   d2: The divisor.

   Returns: The remainder after dividing d1 by d2.
  """
  pass
 @staticmethod
 def Round(d,*__args):
  """
  Round(d: Decimal,mode: MidpointRounding) -> Decimal

  

   Rounds a decimal value to the nearest integer. A parameter specifies how to round the value if 

    it is midway between two other numbers.

  

  

   d: A decimal number to round.

   mode: A value that specifies how to round d if it is midway between two other numbers.

   Returns: The integer that is nearest to the d parameter. If d is halfway between two numbers,one of 

    which is even and the other odd,the mode parameter determines which of the two numbers is 

    returned.

  

  Round(d: Decimal,decimals: int,mode: MidpointRounding) -> Decimal

  

   Rounds a decimal value to a specified precision. A parameter specifies how to round the value if 

    it is midway between two other numbers.

  

  

   d: A decimal number to round.

   decimals: The number of significant decimal places (precision) in the return value.

   mode: A value that specifies how to round d if it is midway between two other numbers.

   Returns: The number that is nearest to the d parameter with a precision equal to the decimals parameter. 

    If d is halfway between two numbers,one of which is even and the other odd,the mode parameter 

    determines which of the two numbers is returned. If the precision of d is less than decimals,d 

    is returned unchanged.

  

  Round(d: Decimal) -> Decimal

  

   Rounds a decimal value to the nearest integer.

  

   d: A decimal number to round.

   Returns: The integer that is nearest to the d parameter. If d is halfway between two integers,one of 

    which is even and the other odd,the even number is returned.

  

  Round(d: Decimal,decimals: int) -> Decimal

  

   Rounds a System.Decimal value to a specified number of decimal places.

  

   d: A decimal number to round.

   decimals: A value from 0 to 28 that specifies the number of decimal places to round to.

   Returns: The decimal number equivalent to d rounded to decimals number of decimal places.
  """
  pass
 @staticmethod
 def Subtract(d1,d2):
  """
  Subtract(d1: Decimal,d2: Decimal) -> Decimal

  

   Subtracts one specified System.Decimal value from another.

  

   d1: The minuend.

   d2: The subtrahend.

   Returns: The result of subtracting d2 from d1.
  """
  pass
 @staticmethod
 def ToByte(value):
  """
  ToByte(value: Decimal) -> Byte

  

   Converts the value of the specified System.Decimal to the equivalent 8-bit unsigned integer.

  

   value: The decimal number to convert.

   Returns: An 8-bit unsigned integer equivalent to value.
  """
  pass
 @staticmethod
 def ToDouble(d):
  """
  ToDouble(d: Decimal) -> float

  

   Converts the value of the specified System.Decimal to the equivalent double-precision 

    floating-point number.

  

  

   d: The decimal number to convert.

   Returns: A double-precision floating-point number equivalent to d.
  """
  pass
 @staticmethod
 def ToInt16(value):
  """
  ToInt16(value: Decimal) -> Int16

  

   Converts the value of the specified System.Decimal to the equivalent 16-bit signed integer.

  

   value: The decimal number to convert.

   Returns: A 16-bit signed integer equivalent to value.
  """
  pass
 @staticmethod
 def ToInt32(d):
  """
  ToInt32(d: Decimal) -> int

  

   Converts the value of the specified System.Decimal to the equivalent 32-bit signed integer.

  

   d: The decimal number to convert.

   Returns: A 32-bit signed integer equivalent to the value of d.
  """
  pass
 @staticmethod
 def ToInt64(d):
  """
  ToInt64(d: Decimal) -> Int64

  

   Converts the value of the specified System.Decimal to the equivalent 64-bit signed integer.

  

   d: The decimal number to convert.

   Returns: A 64-bit signed integer equivalent to the value of d.
  """
  pass
 @staticmethod
 def ToOACurrency(value):
  """
  ToOACurrency(value: Decimal) -> Int64

  

   Converts the specified System.Decimal value to the equivalent OLE Automation Currency value,

    which is contained in a 64-bit signed integer.

  

  

   value: The decimal number to convert.

   Returns: A 64-bit signed integer that contains the OLE Automation equivalent of value.
  """
  pass
 @staticmethod
 def ToSByte(value):
  """
  ToSByte(value: Decimal) -> SByte

  

   Converts the value of the specified System.Decimal to the equivalent 8-bit signed integer.

  

   value: The decimal number to convert.

   Returns: An 8-bit signed integer equivalent to value.
  """
  pass
 @staticmethod
 def ToSingle(d):
  """
  ToSingle(d: Decimal) -> Single

  

   Converts the value of the specified System.Decimal to the equivalent single-precision 

    floating-point number.

  

  

   d: The decimal number to convert.

   Returns: A single-precision floating-point number equivalent to the value of d.
  """
  pass
 def ToString(self,*__args):
  """
  ToString(self: Decimal,provider: IFormatProvider) -> str

  

   Converts the numeric value of this instance to its equivalent string representation using the 

    specified culture-specific format information.

  

  

   provider: An object that supplies culture-specific formatting information.

   Returns: The string representation of the value of this instance as specified by provider.

  ToString(self: Decimal,format: str,provider: IFormatProvider) -> str

  

   Converts the numeric value of this instance to its equivalent string representation using the 

    specified format and culture-specific format information.

  

  

   format: A numeric format string (see Remarks).

   provider: An object that supplies culture-specific formatting information.

   Returns: The string representation of the value of this instance as specified by format and provider.

  ToString(self: Decimal) -> str

  

   Converts the numeric value of this instance to its equivalent string representation.

   Returns: A string that represents the value of this instance.

  ToString(self: Decimal,format: str) -> str

  

   Converts the numeric value of this instance to its equivalent string representation,using the 

    specified format.

  

  

   format: A standard or custom numeric format string (see Remarks).

   Returns: The string representation of the value of this instance as specified by format.
  """
  pass
 @staticmethod
 def ToUInt16(value):
  """
  ToUInt16(value: Decimal) -> UInt16

  

   Converts the value of the specified System.Decimal to the equivalent 16-bit unsigned integer.

  

   value: The decimal number to convert.

   Returns: A 16-bit unsigned integer equivalent to the value of value.
  """
  pass
 @staticmethod
 def ToUInt32(d):
  """
  ToUInt32(d: Decimal) -> UInt32

  

   Converts the value of the specified System.Decimal to the equivalent 32-bit unsigned integer.

  

   d: The decimal number to convert.

   Returns: A 32-bit unsigned integer equivalent to the value of d.
  """
  pass
 @staticmethod
 def ToUInt64(d):
  """
  ToUInt64(d: Decimal) -> UInt64

  

   Converts the value of the specified System.Decimal to the equivalent 64-bit unsigned integer.

  

   d: The decimal number to convert.

   Returns: A 64-bit unsigned integer equivalent to the value of d.
  """
  pass
 @staticmethod
 def Truncate(d):
  """
  Truncate(d: Decimal) -> Decimal

  

   Returns the integral digits of the specified System.Decimal; any fractional digits are discarded.

  

   d: The decimal number to truncate.

   Returns: The result of d rounded toward zero,to the nearest whole number.
  """
  pass
 @staticmethod
 def TryParse(s,*__args):
  """
  TryParse(s: str,style: NumberStyles,provider: IFormatProvider) -> (bool,Decimal)

  

   Converts the string representation of a number to its System.Decimal equivalent using the 

    specified style and culture-specific format. A return value indicates whether the conversion 

    succeeded or failed.

  

  

   s: The string representation of the number to convert.

   style: A bitwise combination of enumeration values that indicates the permitted format of s. A typical 

    value to specify is System.Globalization.NumberStyles.Number.

  

   provider: An object that supplies culture-specific parsing information about s.

   Returns: true if s was converted successfully; otherwise,false.

  TryParse(s: str) -> (bool,Decimal)

  

   Converts the string representation of a number to its System.Decimal equivalent. A return value 

    indicates whether the conversion succeeded or failed.

  

  

   s: The string representation of the number to convert.

   Returns: true if s was converted successfully; otherwise,false.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __cmp__(self,*args):
  """ x.__cmp__(y) <==> cmp(x,y) """
  pass
 def __complex__(self,*args):
  """ __complex__(value: Decimal) -> float """
  pass
 def __div__(self,*args):
  """ x.__div__(y) <==> x/y """
  pass
 def __float__(self,*args):
  """ __complex__(value: Decimal) -> float """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __hash__(self,*args):
  """ x.__hash__() <==> hash(x) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __int__(self,*args):
  """ __int__(value: Decimal) -> int """
  pass
 def __long__(self,*args):
  """ __int__(value: Decimal) -> int """
  pass
 def __mod__(self,*args):
  """ x.__mod__(y) <==> x%y """
  pass
 def __mul__(self,*args):
  """ x.__mul__(y) <==> x*y """
  pass
 def __neg__(self,*args):
  """ x.__neg__() <==> -x """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,value: int)

  __new__(cls: type,value: UInt32)

  __new__(cls: type,value: Int64)

  __new__(cls: type,value: UInt64)

  __new__(cls: type,value: Single)

  __new__(cls: type,value: float)

  __new__(cls: type,bits: Array[int])

  __new__(cls: type,lo: int,mid: int,hi: int,isNegative: bool,scale: Byte)

  __new__[Decimal]() -> Decimal
  """
  pass
 def __nonzero__(self,*args):
  """ __nonzero__(x: Decimal) -> bool """
  pass
 def __pos__(self,*args):
  """
  __pos__(d: Decimal) -> Decimal

  

   Returns the value of the System.Decimal operand (the sign of the operand is unchanged).

  

   d: The operand to return.

   Returns: The value of the operand,d.
  """
  pass
 def __radd__(self,*args):
  """
  __radd__(d1: Decimal,d2: Decimal) -> Decimal

  

   Adds two specified System.Decimal values.

  

   d1: The first value to add.

   d2: The second value to add.

   Returns: The result of adding d1 and d2.
  """
  pass
 def __rdiv__(self,*args):
  """
  __rdiv__(d1: Decimal,d2: Decimal) -> Decimal

  

   Divides two specified System.Decimal values.

  

   d1: The dividend.

   d2: The divisor.

   Returns: The result of dividing d1 by d2.
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(x: Decimal) -> str """
  pass
 def __rmod__(self,*args):
  """
  __rmod__(d1: Decimal,d2: Decimal) -> Decimal

  

   Returns the remainder resulting from dividing two specified System.Decimal values.

  

   d1: The dividend.

   d2: The divisor.

   Returns: The remainder resulting from dividing d1 by d2.
  """
  pass
 def __rmul__(self,*args):
  """
  __rmul__(d1: Decimal,d2: Decimal) -> Decimal

  

   Multiplies two specified System.Decimal values.

  

   d1: The first value to multiply.

   d2: The second value to multiply.

   Returns: The result of multiplying d1 by d2.
  """
  pass
 def __rsub__(self,*args):
  """
  __rsub__(d1: Decimal,d2: Decimal) -> Decimal

  

   Subtracts two specified System.Decimal values.

  

   d1: The minuend.

   d2: The subtrahend.

   Returns: The result of subtracting d2 from d1.
  """
  pass
 def __str__(self,*args):
  pass
 def __sub__(self,*args):
  """ x.__sub__(y) <==> x-y """
  pass
 MaxValue=None
 MinusOne=None
 MinValue=None
 One=None
 Zero=None




class PlacementMode(Enum,IComparable,IFormattable,IConvertible):
 """
 Describes the placement of where a System.Windows.Controls.Primitives.Popup control appears on the screen.

 

 enum PlacementMode,values: Absolute (0),AbsolutePoint (5),Bottom (2),Center (3),Custom (11),Left (9),Mouse (7),MousePoint (8),Relative (1),RelativePoint (6),Right (4),Top (10)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Absolute=None
 AbsolutePoint=None
 Bottom=None
 Center=None
 Custom=None
 Left=None
 Mouse=None
 MousePoint=None
 Relative=None
 RelativePoint=None
 Right=None
 Top=None
 value__=None




class StringFormat(MarshalByRefObject,ICloneable,IDisposable):
 """
 Encapsulates text layout information (such as alignment,orientation and tab stops) display manipulations (such as ellipsis insertion and national digit substitution) and OpenType features. This class cannot be inherited.

 

 StringFormat()

 StringFormat(options: StringFormatFlags)

 StringFormat(options: StringFormatFlags,language: int)

 StringFormat(format: StringFormat)
 """
 def Clone(self):
  """
  Clone(self: StringFormat) -> object

  

   Creates an exact copy of this System.Drawing.StringFormat object.

   Returns: The System.Drawing.StringFormat object this method creates.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: StringFormat)

   Releases all resources used by this System.Drawing.StringFormat object.
  """
  pass
 def GetTabStops(self,firstTabOffset):
  """
  GetTabStops(self: StringFormat) -> (Array[Single],Single)

  

   Gets the tab stops for this System.Drawing.StringFormat object.

   Returns: An array of distances (in number of spaces) between tab stops.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def SetDigitSubstitution(self,language,substitute):
  """
  SetDigitSubstitution(self: StringFormat,language: int,substitute: StringDigitSubstitute)

   Specifies the language and method to be used when local digits are substituted for western 

    digits.

  

  

   language: A National Language Support (NLS) language identifier that identifies the language that will be 

    used when local digits are substituted for western digits. You can pass the 

    System.Globalization.CultureInfo.LCID property of a System.Globalization.CultureInfo object as 

    the NLS language identifier. For example,suppose you create a System.Globalization.CultureInfo 

    object by passing the string "ar-EG" to a System.Globalization.CultureInfo constructor. If you 

    pass the System.Globalization.CultureInfo.LCID property of that System.Globalization.CultureInfo 

    object along with System.Drawing.StringDigitSubstitute.Traditional to the 

    System.Drawing.StringFormat.SetDigitSubstitution(System.Int32,System.Drawing.StringDigitSubstitut

    e) method,then Arabic-Indic digits will be substituted for western digits at display time.

  

   substitute: An element of the System.Drawing.StringDigitSubstitute enumeration that specifies how digits are 

    displayed.
  """
  pass
 def SetMeasurableCharacterRanges(self,ranges):
  """
  SetMeasurableCharacterRanges(self: StringFormat,ranges: Array[CharacterRange])

   Specifies an array of System.Drawing.CharacterRange structures that represent the ranges of 

    characters measured by a call to the 

    System.Drawing.Graphics.MeasureCharacterRanges(System.String,System.Drawing.Font,System.Drawing.R

    ectangleF,System.Drawing.StringFormat) method.

  

  

   ranges: An array of System.Drawing.CharacterRange structures that specifies the ranges of characters 

    measured by a call to the 

    System.Drawing.Graphics.MeasureCharacterRanges(System.String,System.Drawing.Font,System.Drawing.R

    ectangleF,System.Drawing.StringFormat) method.
  """
  pass
 def SetTabStops(self,firstTabOffset,tabStops):
  """
  SetTabStops(self: StringFormat,firstTabOffset: Single,tabStops: Array[Single])

   Sets tab stops for this System.Drawing.StringFormat object.

  

   firstTabOffset: The number of spaces between the beginning of a line of text and the first tab stop.

   tabStops: An array of distances between tab stops in the units specified by the 

    System.Drawing.Graphics.PageUnit property.
  """
  pass
 def ToString(self):
  """
  ToString(self: StringFormat) -> str

  

   Converts this System.Drawing.StringFormat object to a human-readable string.

   Returns: A string representation of this System.Drawing.StringFormat object.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,options: StringFormatFlags)

  __new__(cls: type,options: StringFormatFlags,language: int)

  __new__(cls: type,format: StringFormat)
  """
  pass
 def __str__(self,*args):
  pass
 Alignment=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets horizontal alignment of the string..



Get: Alignment(self: StringFormat) -> StringAlignment



Set: Alignment(self: StringFormat)=value

"""

 DigitSubstitutionLanguage=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the language that is used when local digits are substituted for western digits.



Get: DigitSubstitutionLanguage(self: StringFormat) -> int



"""

 DigitSubstitutionMethod=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the method to be used for digit substitution.



Get: DigitSubstitutionMethod(self: StringFormat) -> StringDigitSubstitute



"""

 FormatFlags=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a System.Drawing.StringFormatFlags enumeration that contains formatting information.



Get: FormatFlags(self: StringFormat) -> StringFormatFlags



Set: FormatFlags(self: StringFormat)=value

"""

 HotkeyPrefix=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.Drawing.Text.HotkeyPrefix object for this System.Drawing.StringFormat object.



Get: HotkeyPrefix(self: StringFormat) -> HotkeyPrefix



Set: HotkeyPrefix(self: StringFormat)=value

"""

 LineAlignment=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the vertical alignment of the string.



Get: LineAlignment(self: StringFormat) -> StringAlignment



Set: LineAlignment(self: StringFormat)=value

"""

 Trimming=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.Drawing.StringTrimming enumeration for this System.Drawing.StringFormat object.



Get: Trimming(self: StringFormat) -> StringTrimming



Set: Trimming(self: StringFormat)=value

"""


 GenericDefault=None
 GenericTypographic=None

